clear all
set more off
cap log close
log using ../output/log, replace text
cap mkdir ../temp

global rx_claims            "../../../raw/marketscan/data/100pct/ccaed2013"
global therapeutic_classes  "../../therapeutic_classes/output/therapeutic_classes"
global ndc_drug_crosswalk   "../../load_formulary_data/output/FDB_NDC_Crosswalk"
global drug_formulary       "../../load_formulary_data/output/Drug_Formulary"

program main
    
    use ndcnum pay using ${rx_claims}, clear
    drop if pay<=0
    destring ndcnum, gen(ndc)
    merge m:1 ndc using ${therapeutic_classes}, assert(1 2 3) keep(3) keepusing(*) nogen
    merge m:1 ndc using ${ndc_drug_crosswalk}, assert(1 2 3) keep(3) keepusing(*) nogen
    rename medid drugid
    egen cost_decile_temp = xtile(pay), by(therapeutic_class) nq(10)
    bys therapeutic_class drugid: egen cost_decile=min(cost_decile_temp)
    bys drugid: keep if _n==1
    keep drugid cost_decile
    save ../temp/cost_decile, replace

    use ndcnum using ${rx_claims}, clear
    gen claims=1
    destring ndcnum, gen(ndc)
    merge m:1 ndc using ${therapeutic_classes}, assert(1 2 3) keep(3) keepusing(*) nogen
    merge m:1 ndc using ${ndc_drug_crosswalk}, assert(1 2 3) keep(3) keepusing(*) nogen
    rename medid drugid
    collapse (sum) claims, by(drugid therapeutic_class therapeutic_class_description)
    bys drugid: keep if _n==1
    egen frequency_decile = xtile(claims), by(therapeutic_class) nq(10)
    keep drugid frequency_decile
    save ../temp/frequency_decile, replace

    use ../temp/cost_decile, clear
    merge 1:1 drugid using ../temp/frequency_decile, assert(1 2 3) keep(1 2 3) keepusing(*) nogen
    save ../output/cost_and_frequency_decile, replace
    
end

*Execute
main
