clear all
set more off
cap log close
log using ../output/log, replace text
cap mkdir ../temp

global drug_level_formulary_top_1_3 "../../drug_level_formulary_top_1_3/output/drug_level_tiers"
global drug_level_formulary_top_4_6 "../../drug_level_formulary_top_4_6/output/drug_level_tiers"
global drug_level_formulary_top_7_10 "../../drug_level_formulary_top_7_10/output/drug_level_tiers"

global drug_level_payments_top_1_3 "../../drug_level_payments_top_1_3/output/drug_level_payments"
global drug_level_payments_top_4_6 "../../drug_level_payments_top_4_6/output/drug_level_payments"
global drug_level_payments_top_7_10 "../../drug_level_payments_top_7_10/output/drug_level_payments"

global coveredlives "../../formulary_plans/output/plans_by_states"

global therapeutic_classes "../../therapeutic_classes/output/therapeutic_classes"
global class_level_incentives "../../therapeutic_class_payments_merge_standardize/output/therapeutic_class_payments"

program main

    clear
    append using ${drug_level_formulary_top_1_3}
    append using ${drug_level_formulary_top_4_6}
    append using ${drug_level_formulary_top_7_10}
    replace restrictive=1 if restrictive==.
    save ../output/drug_level_formulary, replace

    clear
    append using ${drug_level_payments_top_1_3}
    append using ${drug_level_payments_top_4_6}
    append using ${drug_level_payments_top_7_10}    
    save ../output/drug_level_payments, replace

    use ../output/drug_level_formulary, clear
    merge m:1 organizationid unitedstatescode using ${coveredlives}, ///
        assert(1 2 3) keep(3) keepusing(coveredlives) nogen
    merge m:1 id_2 using ../output/drug_level_payments, assert(2 3) keep(3) keepusing(*) nogen
    keep if hix==1 | self_insured_employers==1
    rename ndcnum ndc
    destring ndc, replace
    merge m:1 ndc using ${therapeutic_classes}, ///
        assert(1 2 3) keep(3) keepusing(*)
    merge m:1 therapeutic_class using ${class_level_incentives}, ///
        assert(1 3) keep(3) keepusing(spend_rev_diff_std spend_rev_ratio_std) nogen
    bys therapeutic_class: gen spend_rev_diff_std_temp = spend_rev_diff_std if _n==1
    xtile percentile_temp = spend_rev_diff_std_temp, nquantiles(100)
    bys therapeutic_class: egen percentile = max(percentile_temp)
    gen middle_75 = percentile>=12.5 & percentile<=87.5
    gen middle_50 = percentile>=25 & percentile<=75    
    gen all = 1
    drop percentile percentile_temp
    rename spend_rev_diff_std diff_class
    rename spend_rev_ratio_std ratio_class
    keep organizationid unitedstatescode id_2 number_with_any_spending group restrictive hix ///
        avg_total_spending-total_spend_rev_reins_diff_std coveredlives middle_75 middle_50 all ///
        therapeutic_class diff_class ratio_class
    save ../output/drug_level_compiled, replace
    
end

*Execute
main
