clear all
set more off
cap log close
log using ../output/log, replace text
cap mkdir ../temp

global formulary "../../load_formulary_data/output"
global drug_list "../../drug_id_xwalk/output/drug_list_top_7_10"
global plans "../../formulary_plans/output/plans_by_states"

program main

    use $drug_list, clear
    destring ndcnum, replace
    rename ndcnum ndc
    save ../temp/drug_list, replace

    use drugid using ${formulary}/Drug_Formulary, clear
    rename drugid medid
    bys medid: keep if _n==1
    merge 1:m medid using ${formulary}/FDB_NDC_Crosswalk, assert(1 2 3) keep(3) keepusing(*) nogen
    merge 1:1 ndc using ../temp/drug_list, assert(1 2 3) keep(3) keepusing(*) nogen
    keep medid ndc id id_2
    bys medid: gen n=_n
    save ../temp/ndc_crosswalk, replace
    keep medid
    bys medid: gen number_of_ndcs=_N
    bys medid: keep if _n==1
    save ../temp/medid_list, replace

    use formularyid drugid unifiedtierstatusid using ${formulary}/Drug_Formulary, clear
    duplicates drop
    gen restrictive = inlist(unifiedtierstatusid, 4, 6, 9, 12, 13, 16, 17,  19, 20, 21)
    collapse (mean) restrictive, by(formularyid drugid)
    rename drugid medid
    merge m:1 medid using ../temp/medid_list, assert(1 3) keep(3) keepusing(*) nogen
    expand number_of_ndcs
    bys medid formularyid: gen n=_n
    merge m:1 medid n using ../temp/ndc_crosswalk, assert(3) keep(3) keepusing(*) nogen
    keep formularyid id_2 restrictive
    reshape wide restrictive, i(formularyid) j(id_2)
    merge 1:m formularyid using ${plans}, ///
        assert(1 3) keep(3) ///
        keepusing(organizationid hix self_insured_employers non_self_insured_non_exchange ///
            unitedstatescode) ///
        nogen
    reshape long restrictive, i(organizationid unitedstatescode) j(id_2)
    save ../output/drug_level_tiers, replace

end

*Execute
main
