clear all
set more off
cap log close
log using ../output/log, replace text
cap mkdir ../temp
set matsize 1000

global spending_measures "../../spending_measures/output/spending_measures_2013"
global drug_use_flags "../../drug_level_spending_top_4_6/output/drug_use_flags"
global drug_list "../../drug_id_xwalk/output/drug_list_top_4_6"
global sample "../../sample_restrictions/output/sample_list"
global revenues "../../revenues/Output/revenues"

global variable_list "total_spending rev_reins"

program main
    load_data
    main_measures
end

program load_data
    use ${spending_measures}, clear
    merge 1:1 enrolid using ${drug_use_flags}, assert(1 2 3) keep(3) keepusing(*) nogen
    foreach var of varlist pay* {
        replace `var'=0 if `var'==.
    }
    merge 1:1 enrolid using ${sample}, assert(1 2 3) keep(3) keepusing(*) nogen
    merge 1:1 enrolid using ${revenues}, assert(1 2 3) keep(3) keepusing(*) nogen
    save ../temp/data_loaded, replace
end

program main_measures
    use ${drug_list}, clear
    levelsof ndcnum, local(drugs)
    use ../temp/data_loaded, clear
    sum total_spending, meanonly
    local mean_spending = `r(mean)'
    foreach drug in `drugs' {
        matrix drugs=nullmat(drugs) \ `drug'
        count if pay`drug'==1
        matrix number_with_any_spending=nullmat(number_with_any_spending) \ `r(N)'
        foreach var of varlist ${variable_list}  {
            sum `var' if pay`drug'==1
            if `r(N)' > 0 {
                matrix avg_`var'=nullmat(avg_`var') \ `r(mean)'
            }
            else {
                matrix avg_`var'=nullmat(avg_`var') \ .
            }
        }
    }
    clear
    svmat drugs
    svmat number_with_any_spending
    foreach var in ${variable_list}  {
        svmat avg_`var'
    }
    rename *1 *
    gen total_spend_rev_reins_ratio=avg_total_spending/avg_rev_reins
    gen total_spend_rev_reins_diff=avg_total_spending-avg_rev_reins
    foreach var of varlist total_spend_rev_reins_ratio total_spend_rev_reins_diff {
        sum `var'
        gen `var'_std = (`var' - `r(mean)') / `r(sd)'
    }
    gen id=_n
    merge 1:1 id using ${drug_list}, assert(3) keep(3) keepusing(*) nogen
    save ../output/drug_level_payments, replace
end

*Execute
main
