clear all
set more off
cap log close
log using ../output/log, replace text
cap mkdir ../temp

global formulary "../../load_formulary_data/output"
global pbm "../../load_pbm_data/output/PBM_Relationship"

program main
    collapse_organization_coverage
    create_plan_file
    create_formulary_file
end

program collapse_organization_coverage
    use ${formulary}/Organization_Coverage, clear
    collapse (sum) coveredlives, by(organizationid)
    save ../temp/Organization_Coverage, replace
end

program create_plan_file
    use ${formulary}/Organization_Details, clear
    merge m:1 channelid using ${formulary}/Channel, ///
        assert(2 3) keep(3) keepusing(*) nogen
    merge 1:1 organizationid using ../temp/Organization_Coverage, ///
        assert(1 3) keep(3) keepusing(*) nogen
    replace coveredlives=0 if coveredlives==.
    merge m:1 organizationtypeid using ${formulary}/Organization_Type, ///
        assert(2 3) keep(3) keepusing(*) nogen
    rename organizationid orgid
    merge 1:1 orgid using ${pbm}, assert(2 3) keep(3) keepusing(pbmid) nogen
    rename orgid organizationid
    order organizationid organizationname parentorganizationid parentorganizationname channelid ///
        channeliddesc organizationtypeid organizationtypedesc formularyid coveredlives
    gen self_insured_employers = channelid==1 & organizationtypeid == 4
    gen hix = ///
        organizationtypeid==16 | organizationtypeid==17 | ///
        organizationtypeid==18 | organizationtypeid==19
    keep if self_insured_employers==1 | hix==1
    gen plan_type=.
    replace plan_type=1 if self_insured_employers==1
    replace plan_type=2 if hix==1
    save ../output/plans, replace
    drop coveredlives
    merge 1:m organizationid using ${formulary}/Organization_Coverage, /// 
        assert(1 3) keep(3) keepusing(*) nogen
    egen pbm_state=group(pbmid unitedstatescode)
    save ../output/plans_by_states, replace
end

program create_formulary_file
    use ../output/plans, clear
    collapse (sum) coveredlives, by(formularyid)
    save ../output/formularies, replace
end

*Execute
main
