clear all
set more off
cap log close
log using ../output/log, replace text
cap mkdir ../temp

global formulary "../../load_formulary_data/output"
global therapeutic_classes "../../therapeutic_classes/output/therapeutic_classes"
global cost_and_frequency_quartile "../../cost_and_frequency_quartile/output/cost_and_frequency_quartile"
global cost_and_frequency_decile "../../cost_and_frequency_decile/output/cost_and_frequency_decile"

program main

    use ${formulary}/Drug_Formulary, clear
    rename drugid medid
    bys medid: keep if _n==1
    merge 1:m medid using ${formulary}/FDB_NDC_Crosswalk, assert(1 2 3) keep(3) keepusing(*) nogen
    merge 1:1 ndc using ${therapeutic_classes}, assert(1 2 3) keep(3) keepusing(*) nogen
    replace therapeutic_class=. if therapeutic_class==999
    bys medid: egen therapeutic_class_temp=max(therapeutic_class)
    drop therapeutic_class
    rename therapeutic_class_temp therapeutic_class
    drop if therapeutic_class==.
    bys medid: keep if _n==1
    rename medid drugid
    gen generic = genericorbrand=="Generic"
    gen brand = genericorbrand=="Brand"
    keep drugid therapeutic_class generic brand
    save ../output/therapeutic_classes, replace
    merge 1:1 drugid using ${cost_and_frequency_quartile}, ///
        assert(1 2 3) keep(1 2 3) keepusing(*) nogen
    merge 1:1 drugid using ${cost_and_frequency_decile}, ///
        assert(1 2 3) keep(1 2 3) keepusing(*) nogen
    drop if therapeutic_class==.
    
    preserve
    number_of_drugs_by_class
    save ../output/number_of_drugs_by_class, replace
    restore

    preserve
    keep if cost_quartile==1
    number_of_drugs_by_class
    save ../output/number_of_drugs_by_class_cost_quartile_1, replace
    restore

    preserve
    keep if frequency_quartile==4
    number_of_drugs_by_class
    save ../output/number_of_drugs_by_class_frequency_quartile_4, replace
    restore

    preserve
    keep if cost_decile==1
    number_of_drugs_by_class
    save ../output/number_of_drugs_by_class_cost_decile_1, replace
    restore 

    preserve
    keep if frequency_decile==10
    number_of_drugs_by_class
    save ../output/number_of_drugs_by_class_frequency_decile_10, replace
    restore
    
end

program number_of_drugs_by_class
    gen number_of_drugs_in_class=1
    collapse (sum) number_of_drugs_in_class number_of_drugs_in_class_generic=generic ///
        number_of_drugs_in_class_brand=brand, by(therapeutic_class)
    gen pct_of_drugs_in_class_generic = number_of_drugs_in_class_generic/number_of_drugs_in_class
    keep therapeutic_class number_of_drugs_in_class* pct_of_drugs_in_class_generic
    order therapeutic_class number_of_drugs_in_class* pct_of_drugs_in_class_generic
end

*Execute
main
