clear all
set more off
cap log close
log using ../output/log, replace text
cap mkdir ../temp

global formulary "../../load_formulary_data/output"
global therapeutic_classes "../../formulary_therapeutic_classes/output/therapeutic_classes"
global number_of_drugs_by_class "../../formulary_therapeutic_classes/output/number_of_drugs_by_class"
global plans "../../formulary_plans/output/plans_by_states"
global formularies "../../formulary_plans/output/formularies"

program main
    load_data
    use ../temp/data_loaded_generic, clear
    therapeutic_class_tiers, number(number_of_drugs_in_class_generic)
    save ../output/therapeutic_class_tiers_generic, replace  
    use ../temp/data_loaded_brand, clear
    therapeutic_class_tiers, number(number_of_drugs_in_class_brand)
    save ../output/therapeutic_class_tiers_brand, replace  
end

program load_data
    use formularyid drugid genericorbrand unifiedtierstatusid using ${formulary}/Drug_Formulary ///
        if genericorbrand=="Generic", clear
    merge m:1 drugid using ${therapeutic_classes}, assert(1 3) keep(3) keepusing(*) nogen
    save ../temp/data_loaded_generic, replace
    use formularyid drugid genericorbrand unifiedtierstatusid using ${formulary}/Drug_Formulary ///
        if genericorbrand=="Brand", clear
    merge m:1 drugid using ${therapeutic_classes}, assert(1 3) keep(3) keepusing(*) nogen
    save ../temp/data_loaded_brand, replace
end

program therapeutic_class_tiers
    syntax, number(str)

    duplicates drop
    bys formularyid drugid: gen reps = _N
    gen N=1/reps    
    collapse (sum) N, by(formularyid therapeutic_class unifiedtierstatusid)
    reshape wide N, i(formularyid therapeutic_class) j(unifiedtierstatusid)
    foreach var of varlist N* {
        replace `var'=0 if `var'==.
    }
    rename N* N*_
    reshape wide N*_, i(formularyid) j(therapeutic_class)
    merge 1:m formularyid using ${plans}, assert(1 2 3) keep(3) keepusing(*) nogen
    reshape long N1_ N2_ N4_ N5_ N6_ N8_ N9_ N10_ N11_ N12_ N13_ N16_ N17_ N19_ N20_ N21_, ///
        i(organizationid unitedstatescode)  j(therapeutic_class)
    merge m:1 therapeutic_class using ${number_of_drugs_by_class}, ///
        assert(1 2 3) keep(3) keepusing(*) nogen
    foreach var of varlist N*_ {
        replace `var'=0 if `var'==.
        gen `var'pct = `var'/`number'
    }
    rename N1_ covered 
    rename N2_ generic 
    rename N4_ not_covered 
    rename N5_ preferred 
    rename N6_ specialty 
    rename N8_ unknown 
    rename N9_ restricted_past 
    rename N10_ medical 
    rename N11_ generic_preferred
    rename N12_ covered_past 
    rename N13_ generic_past 
    rename N16_ preferred_past 
    rename N17_ specialty_past 
    rename N19_ unknown_past 
    rename N20_ medical_past 
    rename N21_ generic_preferred_past 
    rename N1_pct covered_pct 
    rename N2_pct generic_pct 
    rename N4_pct not_covered_pct 
    rename N5_pct preferred_pct 
    rename N6_pct specialty_pct 
    rename N8_pct unknown_pct 
    rename N9_pct restricted_past_pct 
    rename N10_pct medical_pct 
    rename N11_pct generic_preferred_pct
    rename N12_pct covered_past_pct 
    rename N13_pct generic_past_pct 
    rename N16_pct preferred_past_pct 
    rename N17_pct specialty_past_pct 
    rename N19_pct unknown_past_pct 
    rename N20_pct medical_past_pct 
    rename N21_pct generic_preferred_past_pct 
    egen listed_pct = rowtotal(*_pct)
    gen not_listed_pct = 1-listed_pct

end

*Execute
main
