* Payment system simulations for LEM;

*Options realmemsize=max; * Let memory size to be the biggest;
options compress=yes;
options obs=max;
options helpbrowser=sas;

libname data "../../../derived/revenues/Output";
libname raw13 "../../../raw/marketscan/data";

* Specify files names;

%LET ip_claims13=s13;
%LET op_claims13=o13;
%LET rx_claims13=d13;
%LET member13=a13;

************************************************************
* IMPORT SPENDING FILE;


libname sasfile "../../../derived/revenues/Output";
libname xptfile xport "../../../derived/revenues/spending.xpt";

proc copy inlib=xptfile outlib=sasfile;
run;

* First, assemble all data;

proc sort data=data.scores; by enrolid; run;
proc sort data=data.&member13; by enrolid; run;
proc sort data=data.spending; by enrolid; run;

data paysys_temp;
	merge data.&member13 data.scores data.spending;
	by enrolid;

	total_spending=total_sp;
	ip_spend=total_in;
	op_spend=total_ou;
	rx_spend=total_rx;

	if score_hhs~=.;

	reins_trans=0;
	if total_spending>60000 then reins_trans=0.8*(total_spending-60000);
	ones=1;
run;

* Import age curve mapping;
proc import datafile="../../../derived/revenues/HHS/age_curve.csv"
     out=age_curve
     dbms=csv
     replace;
     getnames=yes;
run;

proc sort data=paysys_temp; by age; run;
proc sort data=age_curve; by age; run;

data paysys_age;
	merge paysys_temp(in=allowed) age_curve;
	by age;

	if allowed=1;

	rename hhs=age_curve;
run;


* Find means;
proc sort data=paysys_age; by enrolid; run;

proc means data=paysys_age noprint;
	var total_spending reins_trans age_curve score_hhs;
	output out=paysys_means mean=mean_pay reins_prem mean_age_curve mean_score_hhs;
run;

data paysys_means2;
	set paysys_means;
	ones=1;
	keep mean_pay reins_prem mean_age_curve mean_score_hhs ones;
run;

data paysys_merge;
	merge paysys_age paysys_means2;
	by ones;

	rel_hhs=score_hhs/mean_score_hhs;

	rel_age_curve=age_curve/mean_age_curve;

run;

proc means data=paysys_merge noprint;
	var rel_age_curve rel_hhs;
	output out=paysys_relmeans mean=relmean_age relmean_hhs;
run;

data paysys_relmeans2;
	set paysys_relmeans;
	ones=1;
	keep ones relmean_age relmean_hhs;
run;

data data.paysys_hhs;
	merge paysys_merge paysys_relmeans2;
	by ones;

	* Base payment system;
	rev =(rel_hhs/relmean_hhs)*mean_pay;

	* Plus reinsurance;
	rev_reins=(rel_hhs/relmean_hhs)*mean_pay+reins_trans-reins_prem;

run;

data data.revenues;
     set data.paysys_hhs;
     keep enrolid rev rev_reins;
run;






















	

	



