* Estimate risk adjustment models and generate risk scores;

* Initiate some settings;
Options realmemsize=max; * Let memory size to be the biggest;
options compress=yes;
options obs=max;
options helpbrowser=sas;

* Assign libraries;
libname raw13 '../../../raw/marketscan/data';

libname data '../../../derived/revenues/Output';
libname raw '../../../derived/revenues';
libname tmp '../../../derived/revenues/temp';

libname hhs "../../../derived/revenues/HHS";

libname in '../../../derived/revenues/Output';
libname out '../../../derived/revenues/Output';

%Include "../../../derived/revenues/HHS/V0313L1P.SAS";
%Include "../../../derived/revenues/HHS/V0313L1P_hcc.sas";
%Include "../../../derived/revenues/HHS/hhs_procs.sas";


* Open formats (also, don't worry about this);
* FORMATS ALREADY LOADED - WEIRD ERRORS LOADING SOMETIMES, SO COMMENTED THIS OUT;
filename INC "../../../revenues/HHS/C0310L1O.TRN";
libname INCOEF "../../../derived/revenues/HHS";

proc cimport infile=INC data=INCOEF.Coefficients; run;

filename INF "../../../derived/revenues/HHS/H0313L1O.TRN";
libname hhs "../../../derived/revenues/HHS/";

proc cimport infile=INF library=hhs; run;
proc cimport infile=INF library=work; run;

*******************************************************************
* IMPORT ENROLLEE IDS;

libname sasfile "../../../derived/revenues";
libname xptfile xport "../../../derived/revenues/ids.xpt";

proc copy inlib=xptfile outlib=sasfile;
run;


********************************************************************
* Start by generating data files for the smaller sample of enrollees;

proc sort data=raw.ids; by enrolid; run;


data data.o13;
     merge raw.ids(in=sample) raw13.ccaeo131;
     by enrolid;
     if sample=1;
run;

data data.s13;
     merge raw.ids(in=sample) raw13.ccaes131;
     by enrolid;
     if sample=1;
run;



* Specify file name macros;

%LET ip_claims13=s13;
%LET op_claims13=o13;
%LET member13=a13;


******************************************************;
* Generate diagnosis files;
* Need to construct one file with all VALID diagnoses
* Final file should have two variables: enrolid, diag
* One diagnosis per line
* Valid diagnoses are defined in HHS-HCC model documentation
* Different for inpatient/outpatient facility/professional

*-----* Inpatient macros;

%macro inpat(ip_claims,fac_claims,yr);

* Professional claims;

* Import inpatient services file;
data inprof;
     set data.&ip_claims.;

	 * Keep professional claims;
     if FACPROF='P';

     * Identify claims with valid procedure codes;
     hhscode=0;

     proc=pproc;
     %hhs_procs;

     proc=proc1;
     %hhs_procs;

     if hhscode=1;

     keep enrolid caseid dx1 dx2;
run;

* Stack diagnoses so there is one per line;
data inprof1;
     set inprof;
     diag=dx1;
     keep enrolid caseid diag;
run;

data inprof2;
     set inprof;
     diag=dx2;
     keep enrolid caseid diag;
run;


* Facility claims;
proc sort data=data.&ip_claims.; by enrolid fachdid; run;
proc sort data=data.&fac_claims.; by enrolid fachdid; run;

* Merge services file with facility header file;
* Facility diagnoses come from facility header file NOT from services files;
data temp;
     merge data.&ip_claims.(keep=enrolid fachdid caseid facprof) data.&fac_claims.;
     by enrolid fachdid;

	 * Keep facility claims only;
     if FACPROF='F';

	 * Need to identify all claims "related" to a claim with bill type 114;
	 * Define "related" claims as all claims from same admission;
     bill114=0;
     if billtyp='114' then bill114=1;
run;

proc sort data=temp; by enrolid caseid; run;

* Create variable indicating where there is a bill type 114 for each admission
* Admissions indicated by caseid;
proc means data=temp noprint;
     by enrolid caseid;
     var bill114;
     output out=tempmax max=;
run;

proc sort data=temp; by enrolid caseid; run;
proc sort data=tempmax; by enrolid caseid; run;

* Merge bill type 114 back into inpatient facility claims file;
data infac;
     merge temp tempmax;
     by enrolid caseid;
     
	 * Identify valid bill types;
	 * Claims with the following fill types are always valid;
     in_valid=0;
     if billtyp in ('110','111','114','116','117') then in_valid=1;
     if bill114=1 and billtyp in ('112','113') then in_valid=1;

	 * Claims with the following bill types are valid if the procedure is on the
	 	valid procedure list;
     temp=0;
     if billtyp in ('130','131','132','133','134','136','137','711',
                    '712','713','714','715','716','717','718','71F',
                    '71G','71H','71I','71J','71K','71M','71N','71O',
                    '71X','71Y','71Z','731','732','733','734','735',
                    '736','737','738','73F','73G','73H','73I','73J',
                    '73K','73M','73N','73O','73X','73Y','73Z','760',
                    '761','762','763','764','765','766','767','768',
                    '76F','76G','76H','76I','76J','76K','76M','76N',
                    '76O','76X','76Y','76Z') then temp=1;

     hhscode=0;

     proc=proc1;
     %hhs_procs;

     proc=proc2;
     %hhs_procs;

     proc=proc3;
     %hhs_procs;

     proc=proc4;
     %hhs_procs;

     proc=proc5;
     %hhs_procs;

     proc=proc6;
     %hhs_procs;

     out_valid=0;
     if temp=1 and hhscode=1 then out_valid=1;

     if out_valid=1 or in_valid=1;
     keep enrolid caseid dx1 dx2 dx3 dx4 dx5 dx6 dx7 dx8 dx9;
run;

* Construct dataset with one diagnosis per line;
%DO i=1 %TO 9;

data infac&i.;
     set infac;
     diag=dx&i.;
	 if diag~="";
     keep enrolid caseid diag;
run;

%END;

data data.indiags&yr.;
     set inprof1 inprof2 infac1 infac2 infac3 infac4 infac5 infac6 infac7 infac8 infac9;
run;

%MEND;

%inpat(s13,f13,13);

*-----* Outpatient;
* Outpatient notes should be almost the same as inpatient;

%macro outpat(op_claims,fac_claims,yr);

* Professional;
data outprof;
     set data.&op_claims.;

     if FACPROF='P';

     * Identify claims with valid procedure codes;
     hhscode=0;

     proc=proc1;
     %hhs_procs;

     if hhscode=1;

     keep enrolid svcdate dx1 dx2 dx3 dx4;
run;

data outprof1;
     set outprof;
     diag=dx1;
     keep enrolid svcdate diag;
run;

data outprof2;
     set outprof;
     diag=dx2;
     keep enrolid svcdate diag;
run;

data outprof3;
     set outprof;
     diag=dx3;
     keep enrolid svcdate diag;
run;

data outprof4;
     set outprof;
     diag=dx4;
     keep enrolid svcdate diag;
run;

* Facility claims;
proc sort data=data.&op_claims.; by enrolid fachdid; run;
proc sort data=data.&fac_claims.; by enrolid fachdid; run;

data temp;
     merge data.&op_claims. data.&fac_claims.;
     by enrolid fachdid;
     if FACPROF='F';
run;

data outfac;
     set temp;
     
     in_valid=0;
     if billtyp in ('110','111','114','116','117') then in_valid=1;

     temp=0;
     if billtyp in ('130','131','132','133','134','136','137','711',
                    '712','713','714','715','716','717','718','71F',
                    '71G','71H','71I','71J','71K','71M','71N','71O',
                    '71X','71Y','71Z','731','732','733','734','735',
                    '736','737','738','73F','73G','73H','73I','73J',
                    '73K','73M','73N','73O','73X','73Y','73Z','760',
                    '761','762','763','764','765','766','767','768',
                    '76F','76G','76H','76I','76J','76K','76M','76N',
                    '76O','76X','76Y','76Z') then temp=1;

     hhscode=0;

     proc=proc1;
     %hhs_procs;

     proc=proc2;
     %hhs_procs;

     proc=proc3;
     %hhs_procs;

     proc=proc4;
     %hhs_procs;

     proc=proc5;
     %hhs_procs;

     proc=proc6;
     %hhs_procs;

     out_valid=0;
     if temp=1 and hhscode=1 then out_valid=1;

     if out_valid=1 or in_valid=1;
     keep enrolid svcdate dx1 dx2 dx3 dx4 dx5 dx6 dx7 dx8 dx9;
run;

%DO i=1 %TO 9;

data outfac&i.;
     set outfac;
     diag=dx&i.;
	 if diag~="";
     keep enrolid svcdate diag;
run;

%END;

data data.outdiags&yr.;
     set outprof1 outprof2 outprof3 outprof4 outfac1 outfac2 outfac3 outfac4 outfac5 outfac6 outfac7 outfac8 outfac9;
     if diag~='';
run;

%MEND;

%outpat(o13,f13,13);

***********************************************************;
* ESTIMATE RISK ADJUSTMENT MODELS;

*******************;
* HHS-HCC;

* Specify file names;

%LET ip_claims13=s13;
%LET op_claims13=o13;
%LET rx_claims13=d13;
%LET member13=a13;

* Create diag file;
* Stack inpatient/outpatient diagnosis files;

data data.diag;
	set data.outdiags13 data.indiags13;
	keep enrolid diag;
run;

* Create person file;

* Create person dataset for HHS-HCC program;
* Prepare necessary variables;
* AGEFIRST is age at beginning of year
* AGELAST is age at end of year;
* SEX should be character variable;
* METAL doesn't matter, say silver;
* CSR_indicator only used if simulating CSR plans;
	
data data.person;
     set data.&member13.(rename=(sex=sex_num));

     if age>0 then AGE_FIRST=age-1; if age=0 then AGE_FIRST=0;
     AGE_LAST=age;

     if sex_num=1 then SEX="M";
     if sex_num=2 then SEX="F";

     METAL="S";

     CSR_indicator=0;

     keep enrolid AGE_FIRST AGE_LAST SEX METAL CSR_INDICATOR;
run;

* Run HHS-HCC program;

proc sort data=data.person; by enrolid; run;
proc sort data=data.diag; by enrolid; run;

%V0313L1P_hcc;


* Construct dataset with silver risk scores, total spending, and estimate of silver plan costs;
* Additional variables: Months enrolled, age, sex;

proc sort data=out.master; by enrolid; run;
proc sort data=data.&member13.; by enrolid; run;

* Merge enrollment dataset with output data from HHS-HCC program;
data data.scores;
	merge 	data.&member13.(keep=enrolid) 
			out.master(in=valid);
	by enrolid;

	scoreless=0;
	if valid=0 then scoreless=1;

	score_hhs=score_adult_silver;
	if score_hhs=. then score_hhs=score_child_silver;
	if score_hhs=. then score_hhs=score_infant_silver;

	keep enrolid score_hhs;
run;


	



