clear all
set more off
cap log close
log using ../output/log, replace text
cap mkdir ../temp

global data_location "../../../raw/marketscan/data/100pct/"

program main
    coverage_flags
    negative_and_capitation_flags
    previous_enrollment_flags
    sample_restrictions
end

program coverage_flags
    use enrolid enrind* mhsacovg rx using ${data_location}/ccaea2013, clear
    egen number_of_months_enrolled=rowtotal(enrind*)
    gen enrolled_for_12_months_2013=number_of_months_enrolled==12
    gen rx_coverage=rx=="1"
    gen mental_health_coverage=mhsacovg=="1"
    keep enrolid enrolled_for_12_months_2013 mental_health_coverage rx_coverage
    save ../temp/coverage_flags, replace
end

program negative_and_capitation_flags
    local inpatient_file "ccaes2013"
    local outpatient_file "ccaeo2013"
    local inpatient_cap_svc "cap_svc"
    local outpatient_cap_svc "CAP_SVC"
    foreach file in inpatient outpatient {
        use enrolid pay ``file'_cap_svc' using ${data_location}/``file'_file', clear
        gen negative_payment_flag=pay<0
        bys enrolid: egen has_negative_payment_`file'=max(negative_payment)
        gen no_negative_payment_`file'=1-has_negative_payment_`file'
        gen capitated_payment_flag=``file'_cap_svc'=="Y"
        bys enrolid: egen has_capitated_payment_`file'=max(capitated_payment_flag)
        gen no_capitated_payment_`file'=1-has_capitated_payment_`file'
        bys enrolid: keep if _n==1
        keep enrolid no_negative_payment_`file' no_capitated_payment_`file'
        save ../temp/`file'_flags, replace
    }
end

program previous_enrollment_flags
    use enrolid enrind* using ${data_location}/ccaea2012, clear
    egen number_of_months_enrolled=rowtotal(enrind*)
    gen enrolled_for_9_months_2012=number_of_months_enrolled>8
    keep enrolid enrolled_for_9_months_2012
    save ../temp/previous_enrollment_flags, replace    
end

program sample_restrictions
    use enrolid using ${data_location}/ccaea2013, clear
    merge 1:1 enrolid using ../temp/coverage_flags, ///
        assert(3) keep(3) keepusing(*) nogen
    merge 1:1 enrolid using ../temp/inpatient_flags, ///
        assert(1 2 3) keep(1 3) keepusing(*) nogen
    merge 1:1 enrolid using ../temp/outpatient_flags, ///
        assert(1 2 3) keep(1 3) keepusing(*) nogen
    merge 1:1 enrolid using ../temp/previous_enrollment_flags, ///
        assert(1 2 3) keep(1 3) keepusing(*) nogen
    foreach var of varlist no_negative_payment_inpatient no_negative_payment_outpatient ///
        no_capitated_payment_inpatient no_capitated_payment_outpatient {
        replace `var'=1 if `var'==.
    }
    replace enrolled_for_9_months_2012=0 if enrolled_for_9_months_2012==.
    gen in_sample=enrolled_for_12_months_2013&rx_coverage&mental_health_coverage& ///
        no_negative_payment_inpatient&no_negative_payment_outpatient& ///
        no_capitated_payment_inpatient&no_capitated_payment_outpatient&enrolled_for_9_months_2012
    label variable enrolled_for_12_months_2013 "Enrolled for 12 months in 2013"
    label variable rx_coverage "Has Rx coverage"
    label variable mental_health_coverage "Has mental health coverage"
    label variable no_negative_payment_inpatient "No negative payments in inpatient file"
    label variable no_capitated_payment_inpatient "No capitated payments in inpatient file"
    label variable no_negative_payment_outpatient "No negative payments in outpatient file"
    label variable no_capitated_payment_outpatient "No capitated payments in outpatient file"
    label variable enrolled_for_9_months_2012 "Enrolled for at least 9 monts in 2012"
    label variable in_sample "In sample: satisfies all sample restrictions"
    save ../output/sample_restrictions, replace
    keep if in_sample
    keep enrolid
    save ../output/sample_list, replace
end

*Execute
main