clear all
set more off
cap log close
log using ../output/log, replace text
cap mkdir ../temp

global data_location "../../../raw/marketscan/data/100pct/"
global therapeutic_classes "../../therapeutic_classes/output/therapeutic_classes"

program main
    forv year=2012/2013 {
        inpatient_outpatient_spending, year(`year')
        rx_spending, year(`year')
        spending_measures, year(`year')
    }
end

program inpatient_outpatient_spending
    syntax, year(str)

    local inpatient_file "ccaes`year'"
    local outpatient_file "ccaeo`year'"
    foreach file in inpatient outpatient {
        use enrolid pay using ${data_location}/``file'_file', clear
        collapse (sum) total_`file'_spending=pay, by(enrolid)
        save ../temp/`file'_spending_`year', replace
    }

end

program rx_spending
    syntax, year(str)

    use enrolid thercls pay using ${data_location}/ccaed`year' if thercls!=. & thercls!=999, clear  
    collapse (sum) pay, by(enrolid thercls)
    reshape wide pay, i(enrolid) j(thercls)
    rename pay* spending_thercls_*
    foreach var of varlist spending_thercls_* {
        replace `var'=0 if `var'==.
    }
    egen total_rx_spending=rowtotal(spending_thercls_*)
    save ../temp/rx_spending_`year', replace   

end

program spending_measures
    syntax, year(str)

    use enrolid using ${data_location}/ccaea`year', clear
    merge 1:1 enrolid using ../temp/inpatient_spending_`year', ///
        assert(1 2 3) keep(1 3) keepusing(*) nogen
    merge 1:1 enrolid using ../temp/outpatient_spending_`year', ///
        assert(1 2 3) keep(1 3) keepusing(*) nogen
    merge 1:1 enrolid using ../temp/rx_spending_`year', ///
        assert(1 2 3) keep(1 3) keepusing(*) nogen
    merge 1:1 enrolid using ../temp/rx_spending_`year', ///
        assert(1 2 3) keep(1 3) keepusing(*) nogen
    foreach var of varlist total_inpatient_spending total_outpatient_spending total_rx_spending ///
        spending_thercls_* {
        replace `var'=0 if `var'==.
    }
    gen total_spending=total_inpatient_spending + total_outpatient_spending + total_rx_spending
    foreach type in inpatient outpatient rx {
        gen any_`type'_spending=total_`type'_spending>0
    }
    gen any_spending=total_spending>0
    foreach var of varlist spending_thercls_* {
        gen any_`var'=`var'>0
    }
    order enrolid total_inpatient_spending total_outpatient_spending total_rx_spending ///
        total_spending any_inpatient_spending any_outpatient_spending any_rx_spending any_spending
    label variable total_inpatient_spending "Total inpatient spending"
    label variable total_outpatient_spending "Total outpatient spending"
    label variable total_rx_spending "Total Rx spending"
    label variable total_spending "Total spending"
    label variable any_inpatient_spending "Any inpatient spending"
    label variable any_outpatient_spending "Any outpatient spending"
    label variable any_rx_spending "Any Rx spending"
    label variable any_spending "Any spending"
    forv i=1/258 {
        cap label variable spending_thercls_`i' "Spending in therapeutic class `i'"
        cap label variable any_spending_thercls_`i' "Any spending in therapeutic class `i'"
    }
    save ../output/spending_measures_`year', replace

end

*Execute
main