clear all
set more off
cap log close
log using ../output/log, replace text
cap mkdir ../temp
set matsize 5000

global spending_measures "../../spending_measures_ahfs/output/spending_measures_2013"
global sample "../../sample_restrictions/output/sample_list"
global revenues "../../revenues/Output/revenues"

global variable_list "total_inpatient_spending total_outpatient_spending total_rx_spending total_spending rev rev_reins"

program main
    load_data
    main_measures
    class_specific_measures
end

program load_data
    use ${spending_measures}, clear
    merge 1:1 enrolid using ${sample}, assert(1 3) keep(3) keepusing(*) nogen
    merge 1:1 enrolid using ${revenues}, assert(1 3) keep(3) keepusing(*) nogen
    save ../temp/data_loaded, replace
end

program main_measures
    use ../temp/data_loaded, clear
    sum total_spending, meanonly
    local mean_spending = `r(mean)'
    forv i=1/333 {
        capture confirm variable any_spending_thercls_`i'
        if !_rc {
            matrix therapeutic_class=nullmat(therapeutic_class) \ `i'
            count if any_spending_thercls_`i'==1
            matrix number_with_any_spending=nullmat(number_with_any_spending) \ `r(N)'
            foreach var of varlist ${variable_list}  {
                sum `var' if any_spending_thercls_`i'==1
                if `r(N)' > 0 {
                    matrix avg_`var'=nullmat(avg_`var') \ `r(mean)'
                }
                else {
                    matrix avg_`var'=nullmat(avg_`var') \ .
                }
            }
        }
    }
    clear
    svmat therapeutic_class 
    svmat number_with_any_spending
    foreach var in ${variable_list}  {
        svmat avg_`var'
    }
    rename *1 *
    gen total_spend_rev_ratio=avg_total_spending/avg_rev
    gen total_spend_rev_diff=avg_total_spending-avg_rev
    gen total_spend_rev_reins_ratio=avg_total_spending/avg_rev_reins
    gen total_spend_rev_reins_diff=avg_total_spending-avg_rev_reins   
    gen total_spend_meanspend_ratio=avg_total_spending/`mean_spending'
    gen total_spend_meanspend_diff=avg_total_spending-`mean_spending'  
    foreach type in inpatient outpatient rx {
        gen `type'_spend_rev_ratio=avg_total_`type'_spending/avg_rev
        gen `type'_spend_rev_diff=avg_total_`type'_spending-avg_rev
        gen `type'_spend_rev_reins_ratio=avg_total_`type'_spending/avg_rev_reins
        gen `type'_spend_rev_reins_diff=avg_total_`type'_spending-avg_rev_reins
        gen `type'_spend_meanspend_ratio=avg_total_`type'_spending/`mean_spending'
        gen `type'_spend_meanspend_diff=avg_total_`type'_spending-`mean_spending'
    }
    gen avg_total_nonrx_spending=avg_total_inpatient_spending+avg_total_outpatient_spending
    gen nonrx_spend_rev_ratio=avg_total_nonrx_spending/avg_rev
    gen nonrx_spend_rev_diff=avg_total_nonrx_spending-avg_rev
    gen nonrx_spend_rev_reins_ratio=avg_total_nonrx_spending/avg_rev_reins
    gen nonrx_spend_rev_reins_diff=avg_total_nonrx_spending-avg_rev_reins 
    gen nonrx_spend_meanspend_ratio=avg_total_nonrx_spending/`mean_spending'
    gen nonrx_spend_meanspend_diff=avg_total_nonrx_spending-`mean_spending'
    save ../output/therapeutic_class_payments, replace
end

program class_specific_measures
    use ../temp/data_loaded, clear
    forv i=1/333 {
        capture confirm variable any_spending_thercls_`i'
        if !_rc {
            matrix therapeutic_class=nullmat(therapeutic_class) \ `i'
            count if any_spending_thercls_`i'==1
            matrix number_with_any_spending=nullmat(number_with_any_spending) \ `r(N)'
            sum spending_thercls_`i' if any_spending_thercls_`i'==1
            if `r(N)' > 0 {
                matrix avg_class_spending=nullmat(avg_class_spending) \ `r(mean)'
            }
            else {
                matrix avg_class_spending=nullmat(avg_class_spending) \ .
            }
        }
    }
    clear
    svmat therapeutic_class 
    svmat number_with_any_spending    
    svmat avg_class_spending
    rename *1 *    
    save ../output/class_specific_spending, replace
end

*Execute
main