clear all
set more off
set matsize 5000
cap log close
log using ../output/log, replace text
cap mkdir ../temp

global spending_measures_quantiles "../../spending_measures_quantiles/output/spending_measures_quantiles"
global revenues "../../revenues/Output/revenues"

program main
    prepare_data
    regressions
end

program prepare_data
    use ${spending_measures_quantiles}, clear
    merge 1:1 enrolid using ${revenues}, assert(1 2 3) keep(3) keepusing(*) nogen
    gen net_spending_2013=total_spending_2013-rev
    gen net_spending_reins_2013=total_spending_2013-rev_reins
    sum total_spending_2013, meanonly
    gen rel_spending_2013=total_spending_2013-`r(mean)'
    save ../temp/data_prepared, replace
end

program regressions
    use ../temp/data_prepared, clear
    forv i=1/258 {
        capture confirm variable spending_thercls_`i'_2013
        if !_rc {    
            regress spending_thercls_`i'_2013 spending_thercls_*_2012
            predict spending_thercls_`i'_2013_pred, xb
            sum spending_thercls_`i'_2013_pred
            local mean=`r(mean)'
            local sd=`r(sd)'
            corr spending_thercls_`i'_2013_pred net_spending_reins_2013
            local rho_net=`r(rho)'
            corr spending_thercls_`i'_2013_pred rel_spending_2013
            local rho_rel=`r(rho)'
            corr spending_thercls_`i'_2013_pred net_spending_2013
            local rho_net_nr=`r(rho)'
            matrix table = nullmat(table) \ ///
                (`i', `mean', `sd', `sd'/`mean', `rho_net', (`sd'/`mean')*`rho_net', `rho_rel', ///
                (`sd'/`mean')*`rho_rel', `rho_net_nr', (`sd'/`mean')*`rho_net_nr')
        }
    }
    svmat table
    rename table1 therapeutic_class 
    rename table2 mean_spend_pred
    rename table3 sd_spend_pred
    rename table4 cv_spend_pred
    rename table5 corr_spend_pred_spend_net
    rename table6 ellis_mcguire_measure_net
    rename table7 corr_spend_pred_spend_rel
    rename table8 ellis_mcguire_measure_rel
    rename table9 corr_spend_pred_spend_net_nr
    rename table10 ellis_mcguire_measure_net_nr
    save ../output/therapeutic_class_payments_ellis_mcguire, replace
end

*Execute
main
