clear all
set more off
set matsize 5000
cap log close
log using ../output/log, replace text
cap mkdir ../temp

global spending_measures_quantiles "../../spending_measures_quantiles_ahfs/output/spending_measures_quantiles"
global revenues "../../revenues/Output/revenues"

program main
    prepare_data
    level_regression
    quartile_regression
    combine
end

program prepare_data
    use ${spending_measures_quantiles}, clear
    merge 1:1 enrolid using ${revenues}, assert(1 2 3) keep(3) keepusing(*) nogen
    gen net_spending_2013=total_spending_2013-rev
    gen net_spending_reins_2013=total_spending_2013-rev_reins
    sum total_spending_2013, meanonly
    gen rel_spending_2013=total_spending_2013-`r(mean)'
    save ../temp/data_prepared, replace
end

program level_regression
    use ../temp/data_prepared, clear
    forv i=1/333 {
        capture confirm variable spending_thercls_`i'_2013
        if !_rc {    
            regress spending_thercls_`i'_2013 spending_thercls_*_2012
            predict spending_thercls_`i'_2013_pred, xb
            sum spending_thercls_`i'_2013_pred
            local mean=`r(mean)'
            local sd=`r(sd)'
            corr spending_thercls_`i'_2013_pred net_spending_reins_2013
            local rho_net=`r(rho)'
            corr spending_thercls_`i'_2013_pred rel_spending_2013
            local rho_rel=`r(rho)'
            matrix table_level = nullmat(table_level) \ ///
                (`i', `mean', `sd', `sd'/`mean', `rho_net', (`sd'/`mean')*`rho_net', `rho_rel', ///
                (`sd'/`mean')*`rho_rel')
        }
    }
end

program quartile_regression
    use ../temp/data_prepared, clear
    forv i=1/333 {
        capture confirm variable spending_thercls_`i'_2013
        if !_rc {    
            regress spending_thercls_`i'_2013 spending_thercls_*_2012_q*
            predict spending_thercls_`i'_2013_pred, xb
            sum spending_thercls_`i'_2013_pred
            local mean=`r(mean)'
            local sd=`r(sd)'
            corr spending_thercls_`i'_2013_pred net_spending_reins_2013
            local rho_net=`r(rho)'
            corr spending_thercls_`i'_2013_pred rel_spending_2013
            local rho_rel=`r(rho)'
            matrix table_quart = nullmat(table_quart) \ ///
                (`i', `mean', `sd', `sd'/`mean', `rho_net', (`sd'/`mean')*`rho_net', `rho_rel', ///
                (`sd'/`mean')*`rho_rel')
        }
    }
end

program combine
    clear
    foreach table in level quart {
        svmat table_`table'
        rename table_`table'2 mean_spend_pred_`table'
        rename table_`table'3 sd_spend_pred_`table'
        rename table_`table'4 cv_spend_pred_`table'
        rename table_`table'5 corr_spend_pred_spend_net_`table'
        rename table_`table'6 ellis_mcguire_measure_net_`table'
        rename table_`table'7 corr_spend_pred_spend_rel_`table'
        rename table_`table'8 ellis_mcguire_measure_rel_`table'
    }
    rename table_level1 therapeutic_class 
    drop table_quart1
    save ../output/therapeutic_class_payments_ellis_mcguire, replace
end

*Execute
main