clear all
set more off
cap log close
log using ../output/log, replace text
cap mkdir ../temp

global therapeutic_classes      "../../therapeutic_classes/output/therapeutic_classes"
global payments 	            "../../therapeutic_class_payments/output/therapeutic_class_payments"
global payments_classes         "../../therapeutic_class_payments/output/class_specific_spending"
global payments_ellis_mcguire 	"../../therapeutic_class_payments_ellis_mcguire/output/therapeutic_class_payments_ellis_mcguire"

program main
    use therapeutic_class therapeutic_class_description using ${therapeutic_classes}, clear
    bys therapeutic_class: keep if _n==1
    merge 1:1 therapeutic_class using ${payments}, ///
        assert(1 3) keep(3) keepusing(*) nogen
    merge 1:1 therapeutic_class using ${payments_classes}, ///
        assert(1 3) keep(3) keepusing(*) nogen
    merge 1:1 therapeutic_class using ${payments_ellis_mcguire}, ///
        assert(3) keep(3) keepusing(*) nogen
    gen spend_rev_ratio = total_spend_rev_reins_ratio
    gen spend_rev_diff = total_spend_rev_reins_diff
    gen ellis_mcguire = ellis_mcguire_measure_net
    gen spend_rev_ratio_naive = total_spend_meanspend_ratio
    gen spend_rev_diff_naive = total_spend_meanspend_diff
    gen ellis_mcguire_naive = ellis_mcguire_measure_rel
    gen spend_rev_ratio_nr = total_spend_rev_ratio
    gen spend_rev_diff_nr = total_spend_rev_diff
    foreach var of varlist spend_rev_ratio spend_rev_ratio_naive spend_rev_ratio_nr ///
        spend_rev_diff spend_rev_diff_naive spend_rev_diff_nr ///
        ellis_mcguire ellis_mcguire_naive ///
        avg_total_spending avg_class_spending nonrx_spend_rev_ratio nonrx_spend_rev_diff ///
        inpatient_spend_rev_ratio inpatient_spend_rev_diff avg_rev_reins avg_total_rx_spending {
        sum `var'
        gen `var'_std = (`var' - `r(mean)') / `r(sd)'
    }
    drop if number_with_any_spending==0
    save ../output/therapeutic_class_payments, replace
end

*Execute
main
