clear all
set more off
cap log close
log using ../output/log, replace text
cap mkdir ../temp

global therapeutic_classes      "../../therapeutic_classes/output/therapeutic_classes_ahfs"
global payments 	            "../../therapeutic_class_payments_ahfs/output/therapeutic_class_payments"
global payments_classes         "../../therapeutic_class_payments_ahfs/output/class_specific_spending"
global payments_ellis_mcguire 	"../../therapeutic_class_payments_ellis_mcguire_ahfs/output/therapeutic_class_payments_ellis_mcguire"
global efp_elasticities         "../../../raw/efp_elasticities/data/efp_elasticities"

program main
    use therapeutic_class_key therapeutic_class_description using ${therapeutic_classes}, clear
    rename therapeutic_class_key therapeutic_class
    bys therapeutic_class: keep if _n==1
    merge 1:1 therapeutic_class using ${payments}, ///
        assert(1 3) keep(3) keepusing(*) nogen
    merge 1:1 therapeutic_class using ${payments_ellis_mcguire}, ///
        assert(3) keep(3) keepusing(*) nogen
    gen spend_rev_ratio = total_spend_rev_reins_ratio
    gen spend_rev_diff = total_spend_rev_reins_diff
    gen ellis_mcguire = ellis_mcguire_measure_net_level
    foreach var of varlist spend_rev_ratio spend_rev_diff ellis_mcguire {
        sum `var'
        gen `var'_std = (`var' - `r(mean)') / `r(sd)'
    }
    drop if number_with_any_spending==0
    rename therapeutic_class therapeutic_class_key
    merge 1:1 therapeutic_class_key using ${efp_elasticities}, ///
        assert(2 3) keep(3) keepusing(elasticity) nogen
    rename therapeutic_class_key therapeutic_class
    save ../output/therapeutic_class_payments, replace
end

*Execute
main
