clear all
set more off
cap log close
log using ../output/log, replace text
cap mkdir ../temp

global tier_data                "../../derived/formulary_therapeutic_classes_tiers/output/therapeutic_class_tiers"
global payments 	            "../../derived/therapeutic_class_payments_merge_standardize/output/therapeutic_class_payments"
global therapeutic_classes      "../../derived/therapeutic_classes/output/therapeutic_classes"
global rx_claims                "../../raw/marketscan/data/05pct/ccaed2013"
global ndc_drug_crosswalk       "../../derived/load_formulary_data/output/FDB_NDC_Crosswalk"
global drug_formulary           "../../derived/load_formulary_data/output/Drug_Formulary"
global cciio_data               "../../derived/load_cciio_data/output/cciio_data"
global tier_data_ahfs           "../../derived/formulary_therapeutic_classes_tiers_ahfs/output/therapeutic_class_tiers"
global payments_ahfs 	        "../../derived/therapeutic_class_payments_merge_standardize_ahfs/output/therapeutic_class_payments"
global drug_level_incentives    "../../derived/drug_level_compiled/output/drug_level_payments"
global tier_data_brand          "../../derived/formulary_therapeutic_classes_tiers_generics/output/therapeutic_class_tiers_brand"
global tier_data_generic        "../../derived/formulary_therapeutic_classes_tiers_generics/output/therapeutic_class_tiers_generic"

program main
	figure_1
	figure_2
	figure_3
	figure_4
	figure_5
	table_1
	table_2
	table_3
	table_4
	table_5
	table_6
    figure_a1
    figure_a2
    figure_a3
    figure_a4
    figure_a5
    figure_a6
    figure_a7
    figure_a8
    figure_a9
    figure_a10
    table_a1
    table_a2
    table_a3
    table_a4
    table_a5
    table_a6
    table_a7
    table_a8
    table_a9
    table_a10
end

program figure_1

    use ${therapeutic_classes}, clear
    bys therapeutic_class: keep if _n==1
    keep therapeutic_class therapeutic_class_description
    save ../temp/therapeutic_classes, replace
    use ${payments}, clear
    merge 1:m therapeutic_class using ${tier_data}, assert(1 3) keep(3) keepusing(*) nogen
    keep if plan_type==1|plan_type==2
    bys therapeutic_class organizationid: keep if _n==1
    drop if pbmid==-1
    collapse (mean) high_pct non_tier_pct, by(organizationid coveredlives plan_type)
    save ../temp/data_loaded_figure_1, replace

    use ../temp/data_loaded_figure_1, clear
    tw ///
        (histogram high_pct if plan_type==1 [fw=coveredlives], ///
            fcolor(gray) lcolor(black) percent) ///
        (histogram high_pct if plan_type==2 [fw=coveredlives], ///
            fcolor(none) lcolor(black) percent), ///
        legend(on label(1 "Employer plans") label(2 "Exchange plans") size(medium)) ///
        xtitle(Percent on restrictive tier, size(medium)) ytitle(Percent, size(medium)) ///
        scheme(s2mono) graphregion(color(white)) bgcolor(white)
    graph export ../output/figures/1a.pdf, replace

    use ../temp/data_loaded_figure_1, clear
    tw ///
    (histogram non_tier_pct if plan_type==1 [fw=coveredlives], ///
        fcolor(gray) lcolor(black) percent) ///
    (histogram non_tier_pct if plan_type==2 [fw=coveredlives], ///
        fcolor(none) lcolor(black) percent), ///
    legend(on label(1 "Employer plans") label(2 "Exchange plans") size(medium)) ///
    xtitle(Percent PA/ST or not covered, size(medium)) ytitle(Percent, size(medium)) ///
    scheme(s2mono) graphregion(color(white)) bgcolor(white)
    graph export ../output/figures/1b.pdf, replace

end

program figure_2

    use ${payments}, clear
    gen sampleAll=0
    replace sampleAll = (number_with_any_spending>=100)
    sort number_with_any_spending
    gen profit = avg_rev_reins - avg_total_spending
	gen x = 0 in 1
	replace x = 70000 in 2
	gen y = 0 in 1
	replace y = 70000 in 2
	gen sample70 = avg_total_spending<70000 & avg_rev_reins<70000 ///
        & therapeutic_class_d~="None ($844)" & sampleAll==1

    twoway ///
        (scatter y x in 1/2, msymbol(none) connect(l) lpattern(solid) lw(thin) color(maroon)) ///
        (scatter avg_rev_reins avg_total_spending [aweight= number_with_any_spending] ///
            if sample70==1 ,  msymbol(oh) lpattern(solid) lw(vthick) color(black)), ///
        xlabel(0 "$0" 10000 "$10k" 20000 "$20k" 30000 "30k" 40000 "$40k" 50000 "50k" ///
            60000 "$60k" 70000 "$70k", grid labsize(medium))  ///
        ylabel(0 "$0" 10000 "$10k" 20000 "$20k" 30000 "30k" 40000 "$40k" 50000 "50k" ///
            60000 "$60k" 70000 "$70k", grid labsize(medium)) ///
        xtitle("Average Cost by Group", size(medium)) ///
        ytitle("Average Revenue by Group", size(medium)) graphr(c(white) lc(white))  ///
        aspectratio(1) legend(off)
    graph export ../output/figures/2a.pdf, replace

	reg profit avg_total_spending [aweight= number_with_any_spending] if sample70 ==1
    twoway ///
        (lfit profit avg_total_spending [aweight= number_with_any_spending]  if sample70 ==1, ///
            fcolor(none)   msymbol(none) lpattern(dash) lw(medthick) color(gs10)) ///	
        (scatter profit avg_total_spending [aweight= number_with_any_spending]  if sample70 ==1, ///
            msymbol(oh) lpattern(solid) lw(vthick) color(black)), ///
        xlabel(0 "$0" 10000 "$10k" 20000 "$20k" 30000 "30k" 40000 "$40k" 50000 "50k" ///
            60000 "$60k" 70000 "$70k", grid labsize(medium))  ///
        ylabel( -30000 " " -20000 "-$20k" -10000 "-$10k " 0 "$0" 10000 "$10k" 20000 "$20k" ///
            30000 "$30k"  , grid labsize(medium) ) ///
        xtitle("Average Cost by Group", size(medium)) ytitle("Implied Profit", size(medium)) ///
        graphr(c(white) lc(white))  aspectratio(1) yline(0, lcolor(maroon)) legend(off)
	graph export ../output/figures/2b.pdf, replace

end


program figure_3

    use ${therapeutic_classes}, clear
    bys therapeutic_class: keep if _n==1
    keep therapeutic_class therapeutic_class_description
    save ../temp/therapeutic_classes, replace
    use ${payments}, clear
    xtile spend_rev_ratio_std_ventile = spend_rev_ratio_std, nquantiles(20)
    gen in_class = avg_class_spending
    gen out_of_class = avg_total_rx_spending-avg_class_spending
    gen inpatient = avg_total_inpatient_spending
    gen outpatient = avg_total_outpatient_spending
    gen percent_in_class_rx = in_class / avg_total_spending
    gen percent_out_of_class_rx = out_of_class / avg_total_spending
    gen percent_inpatient = inpatient / avg_total_spending
    gen percent_outpatient = outpatient / avg_total_spending
    keep therapeutic_class therapeutic_class_description percent_in_class_rx ///
        percent_out_of_class_rx percent_inpatient percent_outpatient ///
        in_class out_of_class inpatient outpatient spend_rev_ratio_std_ventile
    save ../temp/data_loaded_figure_3, replace

    use ../temp/data_loaded_figure_3, clear
    graph bar percent_*, ///
        over(spend_rev_ratio_std_ventile) stack ///
        legend(on label(1 Percent in class Rx) label(2 Percent out of class Rx) ///
        label(3 Percent inpatient) label(4 Percent outpatient)) ///
        graphregion(color(white)) bgcolor(white)
    graph export ../output/figures/3.pdf, replace
  
end

program figure_4
    use ${payments}, clear
    gen sampleAll=0
    replace sampleAll = (number_with_any_spending>=100)
    local max = _N
    expand 2
    gen origObs = _n
    gen newRev = avg_rev_reins if _n<=`max'
    replace newRev = avg_rev if _n>`max'
    sort therapeutic_class origObs
    cap drop x
    cap drop y 
    gen x = 0 in 1
    replace x = 70000 in 2
    gen y = 0 in 1
    replace y = 70000 in 2
    gen sampleChanges = (sampleAll==1 & avg_total_spending<70000 & avg_rev_reins<70000)
	//dynamically build up the scatterplot command
    quietly levelsof therapeutic_class, local(class) 
    // reset empty
    local gr_code  
    local i = 1
    foreach cl of local class {
        local next = `i'+1
        //green lines for increases in rev, red for decreases in rev
        local positiveChange = avg_rev_reins < avg_rev in `i'
        if `positiveChange'==0{
            local gr_code (scatter newRev avg_total_spending in `i'/`next' if sampleChanges==1 , ///
                lcolor(red) msymbol(none) connect(direct) lpattern(solid) ) `gr_code'
            local gr_code (scatter newRev avg_total_spending in `next' if sampleChanges==1 , ///
                lcolor(red) msymbol(o) mcolor(red) msize(tiny) ) `gr_code'
        }
        if `positiveChange'==1{
            local gr_code (scatter avg_total_spending newRev in `i'/`next' if sampleChanges==1 , ///
                lcolor(green) msymbol(none) connect(direct) lpattern(solid) ) `gr_code'
            di "hi"	
        }		
        local i = `next'+1
    }
    di `i'
    twoway ///
        (scatter y x in 1/2, msymbol(none) connect(l) lpattern(l) lw(thin) color(gs10)) ///
        (scatter avg_total_spending avg_rev if sampleChanges & avg_rev_reins < avg_rev, ///
            msymbol(Th) mcolor(black)) ///
        `gr_code' ///
        (scatter avg_total_spending avg_rev if sampleChanges & avg_rev_reins < avg_rev, ///
            msymbol(Th) mcolor(black)), ///
        xlabel(0 "$0" 10000 "$10k" 20000 "$20k" 30000 "30k" 40000 "$40k" 50000 "50k" ///
            60000 "$60k" 70000 "$70k", grid labsize(mediumsmall))  ///
        ylabel(0 "$0" 10000 "$10k" 20000 "$20k" 30000 "30k" 40000 "$40k" 50000 "50k" ///
            60000 "$60k" 70000 "$70k", grid labsize(mediumsmall)) ///
        ytitle("Average Revenue by Group", size(mediumsmall)) ///
        xtitle("Average Spending by Group", size(mediumsmall)) ///
        graphr(c(white) lc(white))  aspectratio(1) ///
        legend(size(small) order(100 2) label(100 "Revenue Loss, Removing Reinsurance") ///
            label(2 "Indicator for Net Revenue Gain") row(2))
    graph export ../output/figures/4.pdf, replace
end

program figure_5

    global spend_rev_ratio_std_mean "5a"
    global spend_rev_ratio_std_actual "5b"
    global spend_rev_diff_std_mean "5c"
    global spend_rev_diff_std_actual "5d"
    global ellis_mcguire_std_mean "5e"
    global ellis_mcguire_std_actual "5f"

    use ${payments}, clear
    foreach var of varlist spend_rev_ratio_std spend_rev_diff_std ellis_mcguire_std {
        xtile `var'_v = `var', nquantiles(20)
    }
    merge 1:m therapeutic_class using ${tier_data}, assert(1 3) keep(3) keepusing(*) nogen
    keep if plan_type==1|plan_type==2
    bys therapeutic_class organizationid: keep if _n==1
    drop if pbmid==-1
    save ../temp/data_loaded_figure_5, replace

    foreach selection_incentive_measure in spend_rev_ratio_std spend_rev_diff_std ///
        ellis_mcguire_std {
        use ../temp/data_loaded_figure_5 if plan_type==1|plan_type==2, clear
        areg high_pct i.therapeutic_class, a(organizationid)
        predict high_pct_adj, residuals
        collapse (mean) ///
            high_pct_adj `selection_incentive_measure' ///
            [fw=coveredlives], by(`selection_incentive_measure'_v plan_type)
        twoway ///
            (scatter high_pct_adj `selection_incentive_measure' ///
                if plan_type==1, msymbol(square) mcolor(gs10)) ///
            (lfit high_pct_adj `selection_incentive_measure' ///
                if plan_type==1) ///
            (scatter high_pct_adj `selection_incentive_measure' ///
                if plan_type==2, msymbol(oh) mcolor(blue)) ///
            (lfit high_pct_adj `selection_incentive_measure' ///
                if plan_type==2, lcolor(blue)), ///
            xtitle(Mean selection incentive for ventile, size(medium)) ///
            ytitle("Percent on restrictive tier, adjusted", size(medium)) ///
            legend(on label(1 "Employer plans") label(2 "Employer plans (fitted)") ///
                label(3 "Exchange plans") label(4 "Exchange plans (fitted)") ///
                size(medium) region(lwidth(none)))  ///
            scheme(s2mono) graphregion(color(white)) bgcolor(white)
        graph export ../output/figures/${`selection_incentive_measure'_mean}.pdf, replace
        twoway ///
            (scatter high_pct_adj `selection_incentive_measure'_v if plan_type==1, ///
                msymbol(square) mcolor(gs10)) ///
            (lfit high_pct_adj `selection_incentive_measure'_v if plan_type==1) ///
            (scatter high_pct_adj `selection_incentive_measure'_v if plan_type==2, ///
                msymbol(oh) mcolor(blue)) ///
            (lfit high_pct_adj `selection_incentive_measure'_v if plan_type==2, lcolor(blue)), ///
            xtitle(Ventiles of selection incentive, size(medium)) ///
            ytitle("Percent on restrictive tier, adjusted", size(medium)) ///
            legend(on label(1 "Employer plans") label(2 "Employer plans (fitted)") ///
                label(3 "Exchange plans") label(4 "Exchange plans (fitted)") ///
                size(medium) region(lwidth(none))) ///
            scheme(s2mono) graphregion(color(white)) bgcolor(white)
        graph export ../output/figures/${`selection_incentive_measure'_actual}.pdf, replace
    }

end

program table_1

    use ${therapeutic_classes}, clear
    bys therapeutic_class: keep if _n==1
    keep therapeutic_class therapeutic_class_description
    save ../temp/therapeutic_classes, replace
    use ${payments}, clear
    merge 1:m therapeutic_class using ${tier_data}, assert(1 3) keep(3) keepusing(*) nogen
    keep if plan_type==1|plan_type==2
    bys therapeutic_class organizationid: keep if _n==1
    drop if pbmid==-1
    egen past_pct = rowtotal(*_past_pct)
    save ../temp/data_loaded_table_1, replace

    foreach plan_type in 1 2 {
        use ../temp/data_loaded_table_1, clear
        drop if number_with_any_spending==0
        collapse (mean) plan_type coveredlives generic_preferred_pct generic_pct preferred_pct ///
            covered_pct specialty_pct not_listed_pct medical_pct past_pct not_covered_pct ///
            high_pct, by(organizationid)
        count if plan_type == `plan_type'
        matrix summary_table_`plan_type' = `r(N)'
        sum coveredlives if plan_type==`plan_type', meanonly
        matrix summary_table_`plan_type' = summary_table_`plan_type' \ round(`r(mean)',0.001)
        foreach var of varlist generic_preferred_pct generic_pct preferred_pct ///
            covered_pct specialty_pct not_listed_pct medical_pct past_pct not_covered_pct {
            sum `var' if plan_type==`plan_type' [aw=coveredlives], meanonly
            matrix summary_table_`plan_type' = summary_table_`plan_type' \ round(`r(mean)',0.001)
        }
        use ../temp/data_loaded_table_1, clear
        drop if number_with_any_spending==0
        unique therapeutic_class if plan_type==`plan_type'
        matrix summary_table_`plan_type' = summary_table_`plan_type' \ `r(sum)'
        unique therapeutic_class organizationid if plan_type==`plan_type'
        matrix summary_table_`plan_type' = summary_table_`plan_type' \ `r(sum)'
    }
    matrix summary_table = summary_table_1, summary_table_2
    matrix rownames summary_table = ///
        "Number_of_plans" "Mean_lives_covered" "Mean_percent_generic_preferred" ///
        "Mean_percent_generic" "Mean_percent_preferred" "Mean_percent_covered" ///
        "Mean_percent_specialty" "Mean_percent_not_listed" "Mean_percent_medical" ///
        "Mean_percent_PA/ST" "Mean_percent_not_covered" "Therapeutic_classes" ///
        "Therapeutic_classes_\times_Plans"
    matrix colnames summary_table = "Employer_plans" "Exchange_plans"
    estout matrix(summary_table) using  ../output/tables/1.xls, replace

    use ${cciio_data}, clear
    cap drop tagPlanTier
    egen tagPlanTier = tag(StandardComponentId tier csr)
    cap drop sample*
    gen sample1 = tagPlanTier==1
    gen sampleNoCoins = Icoins==0 & tagPlanTier==1
    foreach metal in Silver Silver87 Silver94 {
        foreach tier in 1 2 3 4 { 
            sum max`metal'Copay if tier ==`tier' & MetalLevel=="`metal'" & sampleNoCoins==1 
            matrix `metal'_nocoins = nullmat(`metal'_nocoins) \ `r(mean)'
            count if tier==`tier' & MetalLevel=="`metal'" & sample1==1 
            local N_plans = `r(N)'
            count if tier==`tier' & MetalLevel=="`metal'" & sampleNoCoins==0
            local N_coins = `r(N)'
            local coins_pct = `N_coins' / `N_plans'
            matrix `metal'_pct_coins = nullmat(`metal'_pct_coins) \ `coins_pct'
        }
    }
    matrix CCIIO = Silver_nocoins, Silver87_nocoins, Silver94_nocoins, ///
        Silver_pct_coins, Silver87_pct_coins, Silver94_pct_coins
    matrix rownames CCIIO = "Generic" "PreferredBrand" "Non-PreferredBrand" "Specialty"
    matrix colnames CCIIO =  "SilverNoCoins" "Silver87NoCoins" "Silver94NoCoins" ///
        "SilverCoins" "SilverNoCoins" "SilverNoCoins"
   estout matrix(CCIIO) using  ../output/tables/1.xls, append
      
end

program table_2

    use ${therapeutic_classes}, clear
    bys therapeutic_class: keep if _n==1
    keep therapeutic_class therapeutic_class_description
    save ../temp/therapeutic_classes, replace
    use drugid drugname using ${drug_formulary}, clear
    bys drugid: keep if _n==1
    save ../temp/drug_list, replace
    use ndcnum thercls pay using ${rx_claims}, clear
    gen claims=1
    destring ndcnum, gen(ndc)
    merge m:1 ndc using ${therapeutic_classes}, assert(1 2 3) keep(3) keepusing(*) nogen
    merge m:1 ndc using ${ndc_drug_crosswalk}, assert(1 2 3) keep(3) keepusing(*) nogen
    rename medid drugid
    collapse (sum) claims pay, by(drugid therapeutic_class therapeutic_class_description)
    drop if therapeutic_class==999
    bys drugid: keep if _n==1
    merge 1:1 drugid using ../temp/drug_list, assert(1 2 3) keep(3) keepusing(*) nogen
    gsort therapeutic_class -claims
    by therapeutic_class: keep if _n==1
    keep therapeutic_class drugname
    save ../temp/most_popular_drug, replace
    use ${payments}, clear
    merge 1:m therapeutic_class using ${tier_data}, assert(1 3) keep(3) keepusing(*) nogen
    keep if plan_type==1|plan_type==2
    bys therapeutic_class organizationid: keep if _n==1
    drop if pbmid==-1
    bys therapeutic_class: keep if _n==1
    merge 1:1 therapeutic_class using ../temp/therapeutic_classes, ///
        assert(2 3) keep(3) keepusing(*) nogen
    keep therapeutic_class therapeutic_class_description avg_total_spending avg_rev_reins ///
        number_with_any_spending spend_rev_ratio spend_rev_diff ellis_mcguire
    merge 1:1 therapeutic_class using ../temp/most_popular_drug, assert(1 3) keep(1 3) keepusing(*)
    save ../temp/data_loaded_table_2, replace

    use therapeutic_class therapeutic_class_description drugname avg_total_spending ///
        avg_rev_reins number_with_any_spending spend_rev_diff spend_rev_ratio ellis_mcguire ///
        using ../temp/data_loaded_table_2, clear   
    drop if avg_total_spending==.
    drop if number_with_any_spending<5328
    replace therapeutic_class_description=subinstr(therapeutic_class_description,"&","and",1)
    foreach var of varlist avg_total_spending avg_rev_reins spend_rev_diff {
        replace `var' = round(`var')
        format %9.4gc `var'
    }
    foreach var of varlist spend_rev_ratio ellis_mcguire {
        replace `var' = round(`var', 0.1)
        format %9.4gc `var'        
    }
    keep therapeutic_class_description drugname avg_total_spending /// 
        avg_rev_reins spend_rev_diff spend_rev_ratio ellis_mcguire     
    order therapeutic_class_description drugname avg_total_spending /// 
        avg_rev_reins spend_rev_diff spend_rev_ratio ellis_mcguire
    gsort -spend_rev_diff
    export excel * if _n<11 | _n>128 using ../output/tables/2.xls, firstrow(var) replace

end

program table_3

    use ${payments}, clear
    foreach selection_incentive_measure in spend_rev_ratio_std spend_rev_diff_std ///
        ellis_mcguire_std {
        xtile `selection_incentive_measure'_ventile = `selection_incentive_measure', nquantiles(20)
        tab `selection_incentive_measure'_ventile, gen(`selection_incentive_measure'_ventile_)
    }
    merge 1:m therapeutic_class using ${tier_data}, assert(1 3) keep(3) keepusing(*) nogen
    drop if pbmid==-1
    save ../temp/data_loaded_table_3, replace

    foreach selection_incentive_measure in spend_rev_ratio_std spend_rev_diff_std ///
        ellis_mcguire_std {
        use ../temp/data_loaded_table_3, clear
        rename `selection_incentive_measure' selection_incentive
        rename `selection_incentive_measure'_ventile_20 selection_incentive_ventile_20
        label variable hix "Marketplace"
        label variable selection_incentive "Selection incentive"
        label variable selection_incentive_ventile_20 "Selection incentive ventile 20"
        unique therapeutic_class
        local classes = `r(sum)'
        local observations = `r(N)'
        eststo: areg high_pct 1.hix#c.selection_incentive ///
            i.therapeutic_class [aw=coveredlives], a(organizationid) cluster(therapeutic_class)
        estadd local therapeutic_class_fe "X"
        estadd local plan_fe "X"
        estadd local classes "`classes'"
        estadd local observations "`observations'"
        eststo: areg high_pct 1.hix#c.selection_incentive ///
            1.hix#1.selection_incentive_ventile_20 ///
            i.therapeutic_class [aw=coveredlives], a(organizationid) cluster(therapeutic_class)
        estadd local therapeutic_class_fe "X"
        estadd local plan_fe "X"
        estadd local classes "`classes'"
        estadd local observations "`observations'"
    }
    esttab using ../output/tables/3.csv, b(%9.3fc) se(%9.3fc) parentheses ///
    star(* 0.1 ** 0.05 *** 0.01) noobs label ///
    keep(1.hix#c.selection_incentive 1.hix#1.selection_incentive_ventile_20) ///
    scalars("therapeutic_class_fe Therapeutic Class FE" "plan_fe Plan FE" ///
        "classes Classes" "observations Observations (Plan x Class)") ///
    mtitles("Ratio" "Ratio" "Difference" "Difference" "Ellis-McGuire" "Ellis-McGuire") ///
    title("Panel A: Fraction of Class Tiered Specialty or Higher") replace
    eststo clear

    foreach selection_incentive_measure in spend_rev_ratio_std spend_rev_diff_std ///
        ellis_mcguire_std {
        use ../temp/data_loaded_table_3, clear
        rename `selection_incentive_measure' selection_incentive
        rename `selection_incentive_measure'_ventile_20 selection_incentive_ventile_20
        label variable hix "Marketplace"
        label variable selection_incentive "Selection incentive"
        label variable selection_incentive_ventile_20 "Selection incentive ventile 20"
        unique therapeutic_class
        local classes = `r(sum)'
        local observations = `r(N)'
        eststo: areg non_tier_pct 1.hix#c.selection_incentive ///
            i.therapeutic_class [aw=coveredlives], a(organizationid) cluster(therapeutic_class)
        estadd local therapeutic_class_fe "X"
        estadd local plan_fe "X"
        estadd local classes "`classes'"
        estadd local observations "`observations'"
        eststo: areg non_tier_pct 1.hix#c.selection_incentive ///
            1.hix#1.selection_incentive_ventile_20 ///
            i.therapeutic_class [aw=coveredlives], a(organizationid) cluster(therapeutic_class)
        estadd local therapeutic_class_fe "X"
        estadd local plan_fe "X"
        estadd local classes "`classes'"
        estadd local observations "`observations'"
    }
    esttab using ../output/tables/3.csv, b(%9.3fc) se(%9.3fc) parentheses ///
    star(* 0.1 ** 0.05 *** 0.01) noobs label ///
    keep(1.hix#c.selection_incentive 1.hix#1.selection_incentive_ventile_20) ///
    scalars("therapeutic_class_fe Therapeutic Class FE" "plan_fe Plan FE" ///
        "classes Classes" "observations Observations (Plan x Class)") ///
    mtitles("Ratio" "Ratio" "Difference" "Difference" "Ellis-McGuire" "Ellis-McGuire") ///
    title("Panel B: Fraction of Class Tiered Prior Auth./Step Therapy/Not Covered") append
    eststo clear
  
end

program table_4

    use ${payments}, clear
    foreach selection_incentive_measure in spend_rev_ratio_std spend_rev_diff_std ///
        ellis_mcguire_std avg_total_spending_std avg_total_rx_spending_std {
        xtile `selection_incentive_measure'_v = `selection_incentive_measure', nquantiles(20)
        tab `selection_incentive_measure'_v, gen(`selection_incentive_measure'_v_)
    }
    xtile avg_class_spending_std_v = avg_class_spending_std, nquantiles(20)
    merge 1:m therapeutic_class using ${tier_data}, assert(1 3) keep(3) keepusing(*) nogen
    drop if pbmid==-1
    xi i.hix*i.avg_total_spending_std_v, prefix(tot)
    xi i.hix*i.avg_total_rx_spending_std_v, prefix(rx)
    save ../temp/data_loaded_table_4, replace

    foreach selection_incentive_measure in spend_rev_ratio_std spend_rev_diff_std ///
        ellis_mcguire_std {
        use ../temp/data_loaded_table_4, clear
        rename `selection_incentive_measure' selection_incentive
        label variable hix "Marketplace"
        label variable selection_incentive "Selection incentive"
        label variable avg_total_spending_std "Average total spending"
        unique therapeutic_class
        local classes = `r(sum)'
        local observations = `r(N)'
        eststo: areg high_pct 1.hix#c.selection_incentive 1.hix#c.avg_total_spending_std ///
            i.therapeutic_class [fw=coveredlives], a(organizationid) cluster(therapeutic_class)
        estadd local therapeutic_class_fe "X"
        estadd local plan_fe "X"
        estadd local classes "`classes'"
        estadd local observations "`observations'"
    }
    foreach selection_incentive_measure in spend_rev_ratio_std spend_rev_diff_std ///
        ellis_mcguire_std {
        use ../temp/data_loaded_table_4, clear
        rename `selection_incentive_measure' selection_incentive
        label variable hix "Marketplace"
        label variable selection_incentive "Selection incentive"
        unique therapeutic_class
        local classes = `r(sum)'
        local observations = `r(N)'
        eststo: areg high_pct 1.hix#c.selection_incentive tothixXavg_1_* ///
            i.therapeutic_class [fw=coveredlives], a(organizationid) cluster(therapeutic_class)
        estadd local therapeutic_class_fe "X"
        estadd local plan_fe "X"
        estadd local classes "`classes'"
        estadd local observations "`observations'"
        estadd local bins1 "X"
    }
    esttab using ../output/tables/4.csv, ///
        b(%9.3fc) se(%9.3fc) parentheses star(* 0.1 ** 0.05 *** 0.01) noobs label ///
        keep(1.hix#c.selection_incentive 1.hix#c.avg_total_spending_std) ///
        scalars("bins1 Exchange X [Indicators for 20 total cost bins]" ///
            "therapeutic_class_fe Therapeutic Class FE" "plan_fe Plan FE" ///
            "classes Classes" "observations Observations (Plan \times Class)") ///
        mtitles("Ratio" "Difference" "Ellis-McGuire" "Ratio" "Difference" "Ellis-McGuire") ///
        title("Panel A: Impiled Profits and Total Costs Horserace") replace
    eststo clear

    foreach selection_incentive_measure in spend_rev_ratio_std spend_rev_diff_std ///
        ellis_mcguire_std {
        use ../temp/data_loaded_table_4, clear
        rename `selection_incentive_measure' selection_incentive
        label variable hix "Marketplace"
        label variable selection_incentive "Selection incentive"
        label variable avg_total_rx_spending_std "Average total Rx spending"
        unique therapeutic_class
        local classes = `r(sum)'
        local observations = `r(N)'
        eststo: areg high_pct 1.hix#c.selection_incentive ///
            1.hix#c.avg_total_rx_spending_std i.therapeutic_class [fw=coveredlives], ///
            a(organizationid) cluster(therapeutic_class)
        estadd local therapeutic_class_fe "X"
        estadd local plan_fe "X"
        estadd local classes "`classes'"
        estadd local observations "`observations'"
    }
    foreach selection_incentive_measure in spend_rev_ratio_std spend_rev_diff_std ///
        ellis_mcguire_std {
        use ../temp/data_loaded_table_4, clear
        rename `selection_incentive_measure' selection_incentive
        label variable hix "Marketplace"
        label variable selection_incentive "Selection incentive"
        unique therapeutic_class
        local classes = `r(sum)'
        local observations = `r(N)'
        eststo: areg high_pct 1.hix#c.selection_incentive ///
            rxhixXavg_1_* i.therapeutic_class [fw=coveredlives], ///
            a(organizationid) cluster(therapeutic_class)
        estadd local bins2 "X"
        estadd local therapeutic_class_fe "X"
        estadd local plan_fe "X"
        estadd local classes "`classes'"
        estadd local observations "`observations'"
    }
    esttab using ../output/tables/4.csv, ///
        b(%9.3fc) se(%9.3fc) parentheses star(* 0.1 ** 0.05 *** 0.01) noobs label ///
        keep(1.hix#c.selection_incentive 1.hix#c.avg_total_rx_spending_std) ///
        scalars("bins2 Exchange X [Indicators for 20 Rx cost bins]" ///
            "therapeutic_class_fe Therapeutic Class FE" "plan_fe Plan FE" ///
            "classes Classes" "observations Observations (Plan \times Class)") ///
        mtitles("Ratio" "Difference" "Ellis-McGuire" "Ratio" "Difference" "Ellis-McGuire") ///
        title("Panel B: Implied Profits and Drug Costs Horserace") append
    eststo clear

    foreach selection_incentive_measure in spend_rev_ratio_std spend_rev_diff_std ///
        ellis_mcguire_std {
        use ../temp/data_loaded_table_4, clear
        rename `selection_incentive_measure' selection_incentive
        label variable hix "Marketplace"
        label variable selection_incentive "Selection incentive"
        label variable avg_total_spending_std "Average total spending"
        label variable avg_total_rx_spending_std "Average total Rx spending"
        unique therapeutic_class
        local classes = `r(sum)'
        local observations = `r(N)'
        eststo: areg high_pct 1.hix#c.selection_incentive ///
            1.hix#c.avg_total_spending_std 1.hix#c.avg_total_rx_spending_std ///
            i.therapeutic_class [fw=coveredlives], a(organizationid) cluster(therapeutic_class)
        estadd local therapeutic_class_fe "X"
        estadd local plan_fe "X"
        estadd local classes "`classes'"
        estadd local observations "`observations'"
    }
    foreach selection_incentive_measure in spend_rev_ratio_std spend_rev_diff_std ///
        ellis_mcguire_std {
        use ../temp/data_loaded_table_4, clear
        rename `selection_incentive_measure' selection_incentive
        label variable hix "Marketplace"
        label variable selection_incentive "Selection incentive"
        label variable avg_total_spending_std "Average total spending"
        label variable avg_total_rx_spending_std "Average total Rx spending"
        unique therapeutic_class
        local classes = `r(sum)'
        local observations = `r(N)'
        eststo: areg high_pct 1.hix#c.selection_incentive ///
            tothixXavg_1_*  rxhixXavg_1_* i.therapeutic_class [fw=coveredlives], ///
            a(organizationid) cluster(therapeutic_class)
        estadd local bins1 "X"
        estadd local bins2 "X"
        estadd local therapeutic_class_fe "X"
        estadd local plan_fe "X"
        estadd local classes "`classes'"
        estadd local observations "`observations'"
    }
    esttab using ../output/tables/4.csv, ///
        b(%9.3fc) se(%9.3fc) parentheses star(* 0.1 ** 0.05 *** 0.01) noobs label ///
        keep(1.hix#c.selection_incentive 1.hix#c.avg_total_spending_std ///
            1.hix#c.avg_total_rx_spending_std) ///
        scalars("bins1 Exchange X [Indicators for 20 total cost bins]" ///
            "bins2 Exchange X [Indicators for 20 Rx cost bins]" ///
            "therapeutic_class_fe Therapeutic Class FE" "plan_fe Plan FE" ///
            "classes Classes" "observations Observations (Plan \times Class)") ///
        mtitles("Ratio" "Difference" "Ellis-McGuire" "Ratio" "Difference" "Ellis-McGuire") ///
        title("Panel C: Profits, Drug Costs, and Total Costs Simultaneously") append
    eststo clear

end

program table_5

    foreach data in "_cost_quartile_1" "_frequency_quartile_4" ///
        "_cost_decile_1" "_frequency_decile_10" {
        use ${payments}, clear
        foreach selection_incentive_measure in spend_rev_ratio_std spend_rev_diff_std ///
            ellis_mcguire_std {
            xtile `selection_incentive_measure'_ventile = `selection_incentive_measure', ///
                nquantiles(20)
            tab `selection_incentive_measure'_ventile, gen(`selection_incentive_measure'_ventile_)
        }
        merge 1:m therapeutic_class using ${tier_data}`data', assert(1 3) keep(3) keepusing(*) nogen
        keep if plan_type==1|plan_type==2
        drop if pbmid==-1
        save ../temp/data_loaded_table_5_`data', replace
    }

    foreach data in "_frequency_quartile_4" "_frequency_decile_10" {
        foreach selection_incentive_measure in spend_rev_ratio_std spend_rev_diff_std ///
            ellis_mcguire_std {
            use ../temp/data_loaded_table_5_`data', clear
            rename `selection_incentive_measure' selection_incentive
            label variable hix "Marketplace"
            label variable selection_incentive "Selection incentive"
            unique therapeutic_class
            local classes = `r(sum)'
            local observations = `r(N)'
            eststo: areg high_pct 1.hix#c.selection_incentive ///
                i.therapeutic_class [fw=coveredlives], a(organizationid) cluster(therapeutic_class)
            estadd local therapeutic_class_fe "X"
            estadd local plan_fe "X"
            estadd local classes "`classes'"
            estadd local observations "`observations'"
      }
    }
    esttab using ../output/tables/5.csv, ///
        b(%15.2gc) se(%15.2gc) parentheses star(* 0.1 ** 0.05 *** 0.01) noobs label ///
        keep(1.hix#c.selection_incentive) ///
        scalars("therapeutic_class_fe Therapeutic Class FE" "plan_fe Plan FE" ///
            "classes Classes" "observations Observations (Plan x Class)") ///
        mtitles("Ratio" "Difference" "Ellis-McGuire" "Ratio""Difference" "Ellis-McGuire") ///
        title("Panel A: Most Popular Drugs in Class") replace
    eststo clear

    foreach data in "_cost_quartile_1" "_cost_decile_1" {
        foreach selection_incentive_measure in spend_rev_ratio_std spend_rev_diff_std ///
            ellis_mcguire_std {
            use ../temp/data_loaded_table_5_`data', clear
            rename `selection_incentive_measure' selection_incentive
            label variable hix "Marketplace"
            label variable selection_incentive "Selection incentive"
            unique therapeutic_class
            local classes = `r(sum)'
            local observations = `r(N)'
            eststo: areg high_pct 1.hix#c.selection_incentive ///
                i.therapeutic_class [fw=coveredlives], a(organizationid) cluster(therapeutic_class)
            estadd local therapeutic_class_fe "X"
            estadd local plan_fe "X"
            estadd local classes "`classes'"
            estadd local observations "`observations'"
        }
    }
    esttab using ../output/tables/5.csv, ///
        b(%9.3fc) se(%9.3fc) parentheses star(* 0.1 ** 0.05 *** 0.01) noobs label ///
        keep(1.hix#c.selection_incentive) ///
        scalars("therapeutic_class_fe Therapeutic Class FE" "plan_fe Plan FE" ///
            "classes Classes" "observations Observations (Plan x Class)") ///
        mtitles("Ratio""Difference" "Ellis-McGuire" "Ratio""Difference" "Ellis-McGuire") ///
        title("Panel B: Least Expensive Drugs in Class") append
    eststo clear

end

program table_6

    use ${payments}, clear
    merge 1:m therapeutic_class using ${tier_data}, assert(1 3) keep(3) keepusing(*) nogen
    keep if plan_type==1|plan_type==2
    drop if pbmid==-1
    gen ratio_with_reinsurance = total_spend_rev_reins_ratio
    gen ratio_without_reinsurance = total_spend_rev_ratio
    gen difference_with_reinsurance = total_spend_rev_reins_diff
    gen difference_without_reinsurance = total_spend_rev_diff
    gen em_with_reinsurance = ellis_mcguire_measure_net
    gen em_without_reinsurance = ellis_mcguire_measure_rel_nr
    save ../temp/data_loaded_table_6, replace

    use ../temp/data_loaded_table_6, clear
    foreach selection_incentive_measure in ratio difference em {
        foreach grouping in high_pct non_tier_pct {
            cap drop selection_incentive
            gen selection_incentive = `selection_incentive_measure'_with_reinsurance
            areg `grouping' 1.hix#c.selection_incentive ///
                i.therapeutic_class [aw=coveredlives], a(organizationid) cluster(therapeutic_class)
            predict `selection_incentive_measure'_`grouping'_r
            replace selection_incentive = `selection_incentive_measure'_without_reinsurance
            predict `selection_incentive_measure'_`grouping'_n
        }
    }
    drop selection_incentive
    keep if hix==1
    collapse (mean) ratio_high_pct_r-em_non_tier_pct_n [aw=coveredlives], ///
        by(therapeutic_class therapeutic_class_description)
    foreach grouping in high_pct non_tier_pct {   
        foreach selection_incentive_measure in ratio difference em {
            foreach type in r n {
                sum `selection_incentive_measure'_`grouping'_`type', meanonly
                matrix `grouping' = nullmat(`grouping'), `r(mean)'
            }
        }
        matrix Table_6A = nullmat(Table_6A) \ `grouping'
    }
    
    matrix rownames Table_6A = "PercentOnRestrictiveTier" "PercentNonTier"
    matrix colnames Table_6A = "RatioWithReins" "RatioWithReins" ///
        "DifferenceWithReins" "DifferenceWithReins" "EMWithReins" "EMWithReins"
    estout matrix(Table_6A) using  ../output/tables/6.xls, replace
    foreach selection_incentive_measure in ratio difference em {
        gen change_`selection_incentive_measure' = ///
            `selection_incentive_measure'_high_pct_n - `selection_incentive_measure'_high_pct_r 
        sum change_`selection_incentive_measure', d
        foreach percentile in 1 5 25 50 75 95 99 {
            matrix change_`selection_incentive_measure' = ///
                nullmat(change_`selection_incentive_measure') \ `r(p`percentile')'
        }
        matrix Table_6B = nullmat(Table_6B), change_`selection_incentive_measure'
    }
    matrix rownames Table_6B = "1stPercentile" "5thPercentile" "25thPercentile" "Median" ///
        "75thPercentile" "95thPercentile" "99thPercentile"
    matrix colnames Table_6B = "Ratio" "Difference" "EllisMcGuire"
    estout matrix(Table_6B) using  ../output/tables/6.xls, append
  
end

program figure_a1

    use ${payments}, clear
    gen sampleAll=0
    replace sampleAll = (number_with_any_spending>=100)
    gen sampleApx = therapeutic_class_d~="None ($844)" & sampleAll==1
    gen profit = avg_rev_reins - avg_total_spending

    twoway ///
        (scatter avg_rev_reins avg_total_spending [aweight= number_with_any_spending] ///
            if sampleApx ==1 ,  msymbol(oh) lpattern(solid) lw(vthick) color(black)), ///
        xlabel(0 "$0"100000 "$100k" 200000 "$200k" 300000 "$300k", grid labsize(medium))  ///
        ylabel(0 "$0"100000 "$100k" 200000 "$200k" 300000 "$300k", grid labsize(medium)) ///	
        ytitle("Average Revenue by Group", size(medium)) ///
        xtitle("Average Cost by Group", size(medium))  ///
        graphr(c(white) lc(white))  aspectratio(1) legend(off)
    graph export ../output/figures/A1a.pdf, replace

    reg profit avg_total_spending [aweight= number_with_any_spending] if sampleApx ==1
    twoway ///
        (scatter profit avg_total_spending [aweight= number_with_any_spending]  ///
            if sampleApx ==1, msymbol(oh) lpattern(solid) lw(vthick) color(black)), ///
        xlabel(0 "$0" 100000 "$100k" 200000 "$200k" 300000 "$300k", grid labsize(medium))  ///
        ylabel(-100000 "-$100k" -50000 "-$50k" 0 "$0" 50000 "$50k" 100000 "$100k", ///
            grid labsize(medium)) ///	
        xtitle("Average Cost by Group", size(medium)) ytitle("Implied Profit", size(medium))  ///
        graphr(c(white) lc(white))  aspectratio(1) yline(0, lcolor(maroon)) legend(off)
    graph export ../output/figures/A1b.pdf, replace

    drop sampleApx
    gen sampleApx = therapeutic_class_d~="None ($844)" & avg_total_spending<35000 ///
        & avg_rev_reins<35000 & sampleAll==1
    twoway ///
        (scatter avg_rev_reins avg_total_spending [aweight= number_with_any_spending] ///
            if sampleApx ==1 , msymbol(oh) lpattern(solid) lw(vthick) color(black)), ///
        xlabel(0 "$0" 10000 "$10k" 20000 "$20k" 30000 "30k", grid labsize(medium))  ///
        ylabel(0 "$0" 10000 "$10k" 20000 "$20k" 30000 "30k"  , grid labsize(medium)) ///	
        ytitle("Average Revenue by Group", size(medium)) ///
        xtitle("Average Cost by Group", size(medium))  ///
        graphr(c(white) lc(white))  aspectratio(1) legend(off)
    graph export ../output/figures/A1c.pdf, replace

    reg profit avg_total_spending [aweight= number_with_any_spending] if sampleApx ==1
    twoway ///
        (scatter profit avg_total_spending [aweight= number_with_any_spending]  ///
            if sampleApx ==1, msymbol(oh) lpattern(solid) lw(vthick) color(black)), ///
        xlabel(0 "$0" 10000 "$10k" 20000 "$20k" 30000 "30k", grid labsize(medium))  ///
        ylabel(-20000 "-$20k" -10000 "-$10k " 0 "$0" 10000 "$10k" 20000 "$20k", ///
            grid labsize(medium)) ///	
        xtitle("Average Cost by Group", size(medium)) ytitle("Implied Profit", size(medium))  ///
        graphr(c(white) lc(white))  aspectratio(1) yline(0, lcolor(maroon)) legend(off)
    graph export ../output/figures/A1d.pdf, replace

end

program figure_a2

    use ${payments}, clear
    gen sampleAll=0
    replace sampleAll = (number_with_any_spending>=100)
    gen profit = avg_rev_reins - avg_total_spending
	gen x = 0 in 1
	replace x = 70000 in 2
	gen y = 0 in 1
	replace y = 70000 in 2
	gen sample70 = avg_total_spending<70000 & avg_rev_reins<70000 ///
        & therapeutic_class_d~="None ($844)" & sampleAll==1
    gen spend_noClass = avg_total_spending - avg_class_spending
    gen profit_noClass =  profit + avg_class_spending

    twoway ///
        (scatter y x in 1/2, msymbol(none) connect(l) lpattern(solid) lw(thin) color(maroon)) ///
        (scatter avg_rev_reins spend_noClass [aweight= number_with_any_spending] if sample70==1, ///
            msymbol(oh) lpattern(solid) lw(vthick) color(black)), ///
        xlabel(0 "$0" 10000 "$10k" 20000 "$20k" 30000 "30k" 40000 "$40k" 50000 "50k" ///
            60000 "$60k" 70000 "$70k", grid labsize(medium))  ///
        ylabel(0 "$0" 10000 "$10k" 20000 "$20k" 30000 "30k" 40000 "$40k" 50000 "50k" ///
            60000 "$60k" 70000 "$70k", grid labsize(medium)) ///
        ytitle("Average Revenue by Group", size(medium)) ///
        xtitle("Average Cost by Group", size(medium))  ///
        graphr(c(white) lc(white))  aspectratio(1) legend(off)
    graph export ../output/figures/A2a.pdf, replace

	reg profit avg_total_spending [aweight= number_with_any_spending] if sample70 ==1
    twoway ///
		(lfit profit_noClass spend_noClass [aweight= number_with_any_spending] if sample70 ==1, ///
            fcolor(none)   msymbol(none) lpattern(dash) lw(medthick) color(gs10)) ///	
		(scatter profit_noClass spend_noClass [aweight= number_with_any_spending]  ///
            if sample70 ==1,  msymbol(oh) lpattern(solid) lw(vthick) color(black)), ///
        xlabel(0 "$0" 10000 "$10k" 20000 "$20k" 30000 "30k" 40000 "$40k" 50000 "50k" ///
            60000 "$60k" 70000 "$70k", grid labsize(medium))  ///
		ylabel( -30000 "-$30k" -20000 "-$20k" -10000 "-$10k " 0 "$0" 10000 "$10k" 20000 "$20k" ///
            30000 "$30k", grid labsize(medium)) ///
		xtitle("Average Cost by Group", size(medium)) ytitle("Implied Profit", size(medium))  ///
		graphr(c(white) lc(white))  aspectratio(1) yline(0, lcolor(maroon)) legend(off)		
    graph export ../output/figures/A2b.pdf, replace

end

program figure_a3
    use spend_rev_diff spend_rev_ratio ellis_mcguire using ${payments}, clear
    format spend_rev_diff %10.0gc
    sumround spend_rev_diff, round(1)
    local mean:di %6.0fc `r(mean)'
    local q1:di %6.0fc `r(q1)'
    local median:di %6.0fc `r(median)'
    local q3:di %6.0fc `r(q3)'
    histogram spend_rev_diff, percent scheme(s2mono) ///
        xtitle("Spending-Revenue difference ($)", size(medium)) ytitle(Percent, size(medium)) ///
        subtitle("Mean: `mean' Q1: `q1' Median: `median' Q3: `q3'") ///
        aspectratio(1) graphregion(color(white)) bgcolor(white)
    graph export ../output/figures/A3a.pdf, replace
    sumround spend_rev_ratio, round(0.01)
    histogram spend_rev_ratio, percent scheme(s2mono) ///
        xtitle("Spending/Revenue ratio", size(medium)) ytitle(Percent, size(medium)) ///
        subtitle(Mean: `r(mean)' Q1: `r(q1)' Median: `r(median)' Q3: `r(q3)') ///
        aspectratio(1) graphregion(color(white)) bgcolor(white)
    graph export ../output/figures/A3b.pdf, replace
    sumround ellis_mcguire, round(0.01)
    histogram ellis_mcguire, percent scheme(s2mono) ///
        xtitle("Ellis-McGuire measure", size(medium)) ytitle(Percent, size(medium)) ///
        subtitle(Mean: `r(mean)' Q1: `r(q1)' Median: `r(median)' Q3: `r(q3)') ///
        aspectratio(1) graphregion(color(white)) bgcolor(white)
    graph export ../output/figures/A3c.pdf, replace  
end

    program sumround, rclass
        syntax varlist, round(str)

        sum `varlist', d
        return scalar mean=round(`r(mean)', `round')
        return scalar q1=round(`r(p25)', `round')
        return scalar median=round(`r(p50)', `round')
        return scalar q3=round(`r(p75)', `round')

    end

program figure_a4

    use spend_rev_diff spend_rev_ratio ellis_mcguire using ${payments}, clear
    foreach var of varlist * {
        sort `var'
        gen rank_`var'=_n
    }

    scatter rank_spend_rev_ratio rank_spend_rev_diff, ///
        xtitle(Spending-revenue difference rank, size(medium)) ///
        xscale(range(0 225)) xlabel(0(50)225) xline(111.5) ///
        ytitle(Spending/revenue ratio rank, size(medium)) ///
        yscale(range(0 225)) ylabel(0(50)225) yline(111.5) ///
        scheme(s2mono) graphregion(color(white)) bgcolor(white)
    graph export ../output/figures/A4a.pdf, replace

    scatter rank_ellis_mcguire rank_spend_rev_ratio, ///
        xtitle(Spending/revenue ratio rank, size(medium)) ///
        xscale(range(0 225)) xlabel(0(50)225) xline(111.5) ///
        ytitle(Ellis-McGuire rank, size(medium)) ///
        yscale(range(0 225)) ylabel(0(50)225) yline(111.5) ///
        scheme(s2mono) graphregion(color(white)) bgcolor(white)
    graph export ../output/figures/A4b.pdf, replace

    scatter rank_ellis_mcguire rank_spend_rev_diff, ///
        xtitle(Spending-revenue difference rank, size(medium)) ///
        xscale(range(0 225)) xlabel(0(50)225) xline(111.5) ///
        ytitle(Ellis-McGuire rank, size(medium)) ///
        yscale(range(0 225)) ylabel(0(50)225) yline(111.5) ///
        scheme(s2mono) graphregion(color(white)) bgcolor(white)
    graph export ../output/figures/A4c.pdf, replace

end

program figure_a5

    global spend_rev_ratio_std "A5a"
    global spend_rev_diff_std "A5b"
    global ellis_mcguire_std "A5c"

    use ${payments}, clear
    foreach var of varlist spend_rev_ratio_std spend_rev_diff_std ellis_mcguire_std {
        xtile `var'_v = `var', nquantiles(20)
    }
    merge 1:m therapeutic_class using ${tier_data}, assert(1 3) keep(3) keepusing(*) nogen
    bys therapeutic_class organizationid: keep if _n==1
    drop if pbmid==-1
    save ../temp/data_loaded_figure_a5, replace

    foreach selection_incentive_measure in spend_rev_ratio_std spend_rev_diff_std ///
        ellis_mcguire_std {
        use ../temp/data_loaded_figure_a5, clear
	 set matsize 5000
        xi i.hix*i.therapeutic_class, noomit
        areg high_pct i.therapeutic_class _IhixXthe_1_2-_IhixXthe_1_258, a(organizationid)
        matrix coefficients = 1,0
        forv c=2/258 {
            cap matrix coefficients = coefficients \ (`c', _b[_IhixXthe_1_`c'])
        }
        clear
        svmat coefficients
        rename coefficients1 therapeutic_class
        rename coefficients2 coefficient
        merge 1:1 therapeutic_class using ${payments}, ///
            assert(3) keep(3) keepusing(`selection_incentive_measure')
        xtile ventile = `selection_incentive_measure', nquantiles(20)
        collapse (mean) coefficient `selection_incentive_measure', by(ventile)
        twoway (scatter coefficient `selection_incentive_measure') ///
            (lfitci coefficient `selection_incentive_measure', ciplot(rline)), ///
            xtitle(Mean of selection incentive) ///
            ytitle(Mean adjusted exchange-employer difference) ///
            legend(off) scheme(s2mono) graphregion(color(white)) bgcolor(white)
        graph export ../output/figures/${`selection_incentive_measure'}.pdf, replace
    }

end

program figure_a6

    global spend_rev_ratio_std "A6a"
    global spend_rev_diff_std "A6b"
    global ellis_mcguire_std "A6c"

    use ${payments_ahfs}, clear
    keep if elasticity!=.
    foreach selection_incentive_measure in spend_rev_ratio_std spend_rev_diff_std ///
        ellis_mcguire_std { 
        reg elasticity `selection_incentive_measure'
        local p_value = (2*ttail(e(df_r), ///
            abs(_b[`selection_incentive_measure']/_se[`selection_incentive_measure'])))
        local p_value = round(`p_value',0.01)
        local p_value : di %4.2f `p_value'
        twoway ///
            (scatter elasticity `selection_incentive_measure', msymbol(oh)), ///
            subtitle("p=`p_value'") xtitle("Selection incentive measure", size(medium)) ///
            ytitle("Elasticity", size(medium)) legend(off) ///
            scheme(s2mono) graphregion(color(white)) bgcolor(white)
        graph export ../output/figures/${`selection_incentive_measure'}.pdf, replace 
    }

end

program figure_a7

    use ${drug_level_incentives}, clear
    rename ndcnum ndc
    destring ndc, replace
    save ../temp/drug_level_incentives, replace

    use therapeutic_class total_spend_rev_reins_diff using ${payments}, clear
    xtile percentile = total_spend_rev_reins_diff, nquantiles(100)
    gen middle_75 = percentile>=12.5 & percentile<=87.5
    gen middle_50 = percentile>=25 & percentile<=75
    rename total_spend_rev_reins_diff diff_class
    merge 1:m therapeutic_class using $therapeutic_classes, assert(2 3) keep(3) keepusing(*) nogen
    merge 1:1 ndc using ../temp/drug_level_incentives, assert(1 2 3) keep(3) keepusing(*) nogen
    keep if number_with_any_spending>=1000
    save ../temp/data_loaded_figure_a7, replace

    use spend_rev_diff spend_rev_ratio ellis_mcguire using ${payments}, clear
    format spend_rev_diff %10.0gc
    sumround spend_rev_diff, round(1)
    local mean:di %6.0fc `r(mean)'
    local q1:di %6.0fc `r(q1)'
    local median:di %6.0fc `r(median)'
    local q3:di %6.0fc `r(q3)'
    histogram spend_rev_diff, percent scheme(s2mono) ///
        xtitle("Spending-Revenue difference ($)", size(medium)) ytitle(Percent, size(medium)) ///
        subtitle("Mean: `mean' Q1: `q1' Median: `median' Q3: `q3'") ///
        aspectratio(1) graphregion(color(white)) bgcolor(white)
    graph export ../output/figures/A7a.pdf, replace

    use ../temp/data_loaded_figure_a7, clear
    format total_spend_rev_reins_diff %10.0gc
    sumround total_spend_rev_reins_diff, round(1)
    local mean:di %6.0fc `r(mean)'
    local q1:di %6.0fc `r(q1)'
    local median:di %6.0fc `r(median)'
    local q3:di %6.0fc `r(q3)'
    histogram total_spend_rev_reins_diff, percent scheme(s2mono) ///
        xtitle("Spending-Revenue difference ($)", size(medium)) ///
        ytitle(Percent, size(medium)) ///
        subtitle("Mean: `mean' Q1: `q1' Median: `median' Q3: `q3'") ///
        aspectratio(1) graphregion(color(white)) bgcolor(white)
    graph export ../output/figures/A7b.pdf, replace

    use ../temp/data_loaded_figure_a7 if middle_75==1, clear
    format total_spend_rev_reins_diff %10.0gc
    sumround total_spend_rev_reins_diff, round(1)
    local mean:di %6.0fc `r(mean)'
    local q1:di %6.0fc `r(q1)'
    local median:di %6.0fc `r(median)'
    local q3:di %6.0fc `r(q3)'
    histogram total_spend_rev_reins_diff, percent scheme(s2mono) ///
        xtitle("Spending-Revenue difference ($)", size(medium)) ///
        ytitle(Percent, size(medium)) ///
        subtitle("Mean: `mean' Q1: `q1' Median: `median' Q3: `q3'") ///
        aspectratio(1) graphregion(color(white)) bgcolor(white)
    graph export ../output/figures/A7c.pdf, replace

    use ../temp/data_loaded_figure_a7 if middle_50==1, clear
    format total_spend_rev_reins_diff %10.0gc
    sumround total_spend_rev_reins_diff, round(1)
    local mean:di %6.0fc `r(mean)'
    local q1:di %6.0fc `r(q1)'
    local median:di %6.0fc `r(median)'
    local q3:di %6.0fc `r(q3)'
    histogram total_spend_rev_reins_diff, percent scheme(s2mono) ///
        xtitle("Spending-Revenue difference ($)", size(medium)) ///
        ytitle(Percent, size(medium)) ///
        subtitle("Mean: `mean' Q1: `q1' Median: `median' Q3: `q3'") ///
        aspectratio(1) graphregion(color(white)) bgcolor(white)
    graph export ../output/figures/A7d.pdf, replace

end

program figure_a8

    use ${drug_level_incentives}, clear
    rename ndcnum ndc
    destring ndc, replace
    save ../temp/drug_level_incentives, replace

    use therapeutic_class total_spend_rev_reins_diff using ${payments}, clear
    xtile percentile = total_spend_rev_reins_diff, nquantiles(100)
    gen middle_75 = percentile>=12.5 & percentile<=87.5
    gen middle_50 = percentile>=25 & percentile<=75
    rename total_spend_rev_reins_diff diff_class
    merge 1:m therapeutic_class using $therapeutic_classes, assert(2 3) keep(3) keepusing(*) nogen
    merge 1:1 ndc using ../temp/drug_level_incentives, assert(1 2 3) keep(3) keepusing(*) nogen
    keep if number_with_any_spending>=1000
    save ../temp/data_loaded_figure_a8, replace

    use ${payments}, clear
    gen sampleAll=0
    replace sampleAll = (number_with_any_spending>=100)
    sort number_with_any_spending
    gen profit = avg_rev_reins - avg_total_spending
	gen x = 0 in 1
	replace x = 70000 in 2
	gen y = 0 in 1
	replace y = 70000 in 2
	gen sample70 = avg_total_spending<70000 & avg_rev_reins<70000 ///
        & therapeutic_class_d~="None ($844)" & sampleAll==1
    twoway ///
        (scatter y x in 1/2, msymbol(none) connect(l) lpattern(solid) lw(thin) color(maroon)) ///
        (scatter avg_rev_reins avg_total_spending [aweight= number_with_any_spending] ///
            if sample70==1 ,  msymbol(oh) lpattern(solid) lw(vthick) color(black)), ///
        xlabel(0 "$0" 10000 "$10k" 20000 "$20k" 30000 "30k" 40000 "$40k" 50000 "50k" ///
            60000 "$60k" 70000 "$70k", grid labsize(medium))  ///
        ylabel(0 "$0" 10000 "$10k" 20000 "$20k" 30000 "30k" 40000 "$40k" 50000 "50k" ///
            60000 "$60k" 70000 "$70k", grid labsize(medium)) ///
        xtitle("Average Cost by Group", size(medium)) ///
        ytitle("Average Revenue by Group", size(medium)) graphr(c(white) lc(white))  ///
        aspectratio(1) legend(off)
    graph export ../output/figures/A8a.pdf, replace

    use id_2 avg_total_spending avg_rev_reins number_with_any_spending group ///
        using ../temp/data_loaded_figure_a8 if number_with_any_spending>=1000, clear
    keep if avg_total_spending<70000 & avg_rev_reins<70000
    twoway ///
        (scatter avg_rev_reins avg_total_spending [w=number_with_any_spending], ///
            mcolor(black) msymbol(oh)) ///
        (function y=x, ra(avg_rev_reins)lpattern(solid) lw(thin) color(maroon)), ///
        ytitle("Average simulated revenue ($)") xtitle("Average total spending ($)") ///
        legend(off) ///
        xlabel(0 "$0" 10000 "$10k" 20000 "$20k" 30000 "30k" 40000 "$40k" 50000 "50k" 60000 ///
            "$60k" 70000 "$70k"  , grid labsize(medium)) ///
        ylabel(0 "$0" 10000 "$10k" 20000 "$20k" 30000 "30k" 40000 "$40k" 50000 "50k" 60000 ///
            "$60k" 70000 "$70k"  , grid labsize(medium)) ///
        ytitle("Average Revenue by Drug", size(medium)) ///
        xtitle("Average Cost by Drug", size(medium)) graphr(c(white) lc(white))  ///
        aspectratio(1) scheme(s2mono)
    graph export ../output/figures/A8b.pdf, replace

    use id_2 avg_total_spending avg_rev_reins number_with_any_spending group middle_75 ///
        using ../temp/data_loaded_figure_a8 if number_with_any_spending>=1000 & middle_75==1, clear
    keep if avg_total_spending<70000 & avg_rev_reins<70000
    twoway ///
        (scatter avg_rev_reins avg_total_spending [w=number_with_any_spending], ///
            mcolor(black) msymbol(oh)) ///
        (function y=x, ra(avg_rev_reins)lpattern(solid) lw(thin) color(maroon)), ///
        ytitle("Average simulated revenue ($)") xtitle("Average total spending ($)") ///
        legend(off) ///
        xlabel(0 "$0" 10000 "$10k" 20000 "$20k" 30000 "30k" 40000 "$40k" 50000 "50k" 60000 ///
            "$60k" 70000 "$70k"  , grid labsize(medium)) ///
        ylabel(0 "$0" 10000 "$10k" 20000 "$20k" 30000 "30k" 40000 "$40k" 50000 "50k" 60000 ///
            "$60k" 70000 "$70k"  , grid labsize(medium)) ///
        ytitle("Average Revenue by Drug", size(medium)) ///
        xtitle("Average Cost by Drug", size(medium)) graphr(c(white) lc(white))  ///
        aspectratio(1) scheme(s2mono)
    graph export ../output/figures/A8c.pdf, replace

    use id_2 avg_total_spending avg_rev_reins number_with_any_spending group middle_50 ///
        using ../temp/data_loaded_figure_a8 if number_with_any_spending>=1000 & middle_50==1, clear
    keep if avg_total_spending<70000 & avg_rev_reins<70000
    twoway ///
        (scatter avg_rev_reins avg_total_spending [w=number_with_any_spending], ///
            mcolor(black) msymbol(oh)) ///
        (function y=x, ra(avg_rev_reins)lpattern(solid) lw(thin) color(maroon)), ///
        ytitle("Average simulated revenue ($)") xtitle("Average total spending ($)") ///
        legend(off) ///
        xlabel(0 "$0" 10000 "$10k" 20000 "$20k" 30000 "30k" 40000 "$40k" 50000 "50k" 60000 ///
            "$60k" 70000 "$70k"  , grid labsize(medium)) ///
        ylabel(0 "$0" 10000 "$10k" 20000 "$20k" 30000 "30k" 40000 "$40k" 50000 "50k" 60000 ///
            "$60k" 70000 "$70k"  , grid labsize(medium)) ///
        ytitle("Average Revenue by Drug", size(medium)) ///
        xtitle("Average Cost by Drug", size(medium)) graphr(c(white) lc(white))  ///
        aspectratio(1) scheme(s2mono)
    graph export ../output/figures/A8d.pdf, replace

end

program figure_a9
    use ${payments_ahfs}, clear
    keep if avg_total_spending<100000 & avg_rev<50000
    twoway ///
        (scatter avg_total_spending avg_rev [aweight=number_with_any_spending], ///
            msymbol(oh)) ///
        (scatter avg_total_spending avg_rev if elasticity!=. [aweight=number_with_any_spending], ///
            msymbol(oh) mcolor(blue)) ///
        (function y=x, ra(avg_rev) clpat(dash)), ///
        xtitle("Average simulated revenue ($)", size(medium)) xlabel(0(20000)80000, grid gmax) ///
        ytitle("Average total spending ($)", size(medium)) ylabel(0(20000)80000, grid gmax) ///
        legend(off) scheme(s2mono) graphregion(color(white)) bgcolor(white) aspect(1)
    graph export ../output/figures/A9.pdf, replace
end

program figure_a10

    use ${payments_ahfs}, clear
    xtile spend_rev_ratio_std_v = spend_rev_ratio_std, nquantiles(20)
    merge 1:m therapeutic_class using ${tier_data}, assert(1 3) keep(3) keepusing(*) nogen
    bys therapeutic_class organizationid: keep if _n==1
    drop if pbmid==-1
    save ../temp/data_loaded_figure_a10, replace

    use ../temp/data_loaded_figure_a10, clear
    areg high_pct i.therapeutic_class, a(organizationid)
    predict high_pct_adj, residuals
    collapse (mean) high_pct_adj spend_rev_ratio_std ///
        [fw=coveredlives], by(spend_rev_ratio_std_v plan_type)
    twoway ///
        (scatter high_pct_adj spend_rev_ratio_std_v if plan_type==1, ///
            msymbol(square) mcolor(gs10)) ///
        (lfit high_pct_adj spend_rev_ratio_std_v if plan_type==1) ///
        (scatter high_pct_adj spend_rev_ratio_std_v if plan_type==2, msymbol(oh) mcolor(blue)) ///
        (lfit high_pct_adj spend_rev_ratio_std_v if plan_type==2, lcolor(blue)), ///
        xtitle(Ventiles of selection incentive, size(medium)) ///
        ytitle("Percent on restrictive tier, adjusted", size(medium)) ///
        legend(on label(1 "Employer plans") label(2 "Employer plans (fitted)") ///
            label(3 "Exchange plans") label(4 "Exchange plans (fitted)") ///
            size(medium) region(lwidth(none))) ///
        scheme(s2mono) graphregion(color(white)) bgcolor(white)
    graph export ../output/figures/A10a.pdf, replace
    twoway ///
        (scatter high_pct_adj spend_rev_ratio_std if plan_type==1, msymbol(square) mcolor(gs10)) ///
        (lfit high_pct_adj spend_rev_ratio_std if plan_type==1) ///
        (scatter high_pct_adj spend_rev_ratio_std if plan_type==2, msymbol(oh) mcolor(blue)) ///
        (lfit high_pct_adj spend_rev_ratio_std if plan_type==2, lcolor(blue)), ///
        xtitle(Mean selection incentive for ventile, size(medium)) ///
        ytitle("Percent on restrictive tier, adjusted", size(medium)) ///
        legend(on label(1 "Employer plans") label(2 "Employer plans (fitted)") ///
            label(3 "Exchange plans") label(4 "Exchange plans (fitted)") ///
            size(medium) region(lwidth(none))) ///
        scheme(s2mono) graphregion(color(white)) bgcolor(white)
    graph export ../output/figures/A10b.pdf, replace

end

program table_a1

    use ${payments}, clear
    foreach selection_incentive_measure in spend_rev_ratio_std spend_rev_diff_std ///
        ellis_mcguire_std {
        xtile `selection_incentive_measure'_ventile = `selection_incentive_measure', nquantiles(20)
        tab `selection_incentive_measure'_ventile, gen(`selection_incentive_measure'_ventile_)
    }
    merge 1:m therapeutic_class using ${tier_data}, assert(1 3) keep(3) keepusing(*) nogen
    drop if pbmid==-1
    save ../temp/data_loaded_table_a1, replace

    foreach selection_incentive_measure in spend_rev_ratio_std spend_rev_diff_std ///
        ellis_mcguire_std {
        foreach grouping in high_pct non_tier_pct {    
            use ../temp/data_loaded_table_a1, clear
            rename `selection_incentive_measure' selection_incentive
            rename `selection_incentive_measure'_ventile selection_incentive_ventile
            rename `selection_incentive_measure'_ventile_1 selection_incentive_ventile_1
            rename `selection_incentive_measure'_ventile_18 selection_incentive_ventile_18
            rename `selection_incentive_measure'_ventile_19 selection_incentive_ventile_19
            rename `selection_incentive_measure'_ventile_20 selection_incentive_ventile_20
            label variable hix "Marketplace"
            label variable selection_incentive "Selection incentive"
            label variable selection_incentive_ventile "Selection incentive ventile"
            label variable selection_incentive_ventile_1 "Selection incentive ventile 1"
            label variable selection_incentive_ventile_18 "Selection incentive ventile 18"
            label variable selection_incentive_ventile_19 "Selection incentive ventile 19"
            label variable selection_incentive_ventile_20 "Selection incentive ventile 20"
            unique therapeutic_class
            local classes = `r(sum)'
            local observations = `r(N)'
            eststo: areg `grouping' 1.hix#c.selection_incentive ///
                i.therapeutic_class [aw=coveredlives], a(organizationid) cluster(therapeutic_class)
            estadd local therapeutic_class_fe "X"
            estadd local plan_fe "X"
            estadd local classes "`classes'"
            estadd local observations "`observations'"
            eststo: areg `grouping' 1.hix#c.selection_incentive ///
                1.hix#1.selection_incentive_ventile_20 ///
                i.therapeutic_class [aw=coveredlives], a(organizationid) cluster(therapeutic_class)
            estadd local therapeutic_class_fe "X"
            estadd local plan_fe "X"
            estadd local classes "`classes'"
            estadd local observations "`observations'"
            eststo: areg `grouping' 1.hix#c.selection_incentive ///
                1.hix#1.selection_incentive_ventile_19 ///
                1.hix#1.selection_incentive_ventile_20 ///
                i.therapeutic_class [aw=coveredlives], a(organizationid) cluster(therapeutic_class)
            estadd local therapeutic_class_fe "X"
            estadd local plan_fe "X"
            estadd local classes "`classes'"
            estadd local observations "`observations'"
            eststo: areg `grouping' 1.hix#c.selection_incentive ///
                1.hix#1.selection_incentive_ventile_18 ///
                1.hix#1.selection_incentive_ventile_19 ///
                1.hix#1.selection_incentive_ventile_20 ///
                i.therapeutic_class [aw=coveredlives], a(organizationid) cluster(therapeutic_class)
            estadd local therapeutic_class_fe "X"
            estadd local plan_fe "X"
            estadd local classes "`classes'"
            estadd local observations "`observations'"
            eststo: areg `grouping'  1.hix#1.selection_incentive_ventile_1 ///
                1.hix#1.selection_incentive_ventile_18 ///
                1.hix#1.selection_incentive_ventile_19 ///
                1.hix#1.selection_incentive_ventile_20 ///
                i.therapeutic_class [aw=coveredlives], a(organizationid) cluster(therapeutic_class)
            estadd local therapeutic_class_fe "X"
            estadd local plan_fe "X"
            estadd local classes "`classes'"
            estadd local observations "`observations'"
        }
        esttab using ../output/tables/A1.csv, b(%9.3fc) se(%9.3fc) parentheses ///
            star(* 0.1 ** 0.05 *** 0.01) noobs label ///
            keep(1.hix#c.selection_incentive 1.hix#1.selection_incentive_ventile_1 ///
                1.hix#1.selection_incentive_ventile_18 1.hix#1.selection_incentive_ventile_19 ///
                1.hix#1.selection_incentive_ventile_20) ///
            scalars("therapeutic_class_fe Therapeutic Class FE" "plan_fe Plan FE" ///
                "classes Classes" "observations Observations (Plan x Class)") ///
            mtitles("high_pct" "high_pct" "high_pct" "high_pct" "high_pct" ///
                "non_tier_pct" "non_tier_pct" "non_tier_pct" "non_tier_pct" "non_tier_pct") ///
            title("`selection_incentive_measure'") append
        eststo clear
    }
end

program table_a2

    use ${payments}, clear
    foreach var in avg_total_rx_spending avg_total_spending {
        xtile `var'_decile = `var', nquantiles(10)
        xtile `var'_ventile = `var', nquantiles(20)
    }
    merge 1:m therapeutic_class using ${tier_data}, assert(1 3) keep(3) keepusing(*) nogen
    drop if pbmid==-1
    save ../temp/data_loaded_table_a2, replace

    foreach selection_incentive_measure in spend_rev_ratio_std spend_rev_diff_std ///
        ellis_mcguire_std {
        foreach grouping in high_pct non_tier_pct {    
            foreach cost_grouping in avg_total_rx_spending_decile avg_total_rx_spending_ventile ///
                avg_total_spending_decile avg_total_spending_ventile {
                use ../temp/data_loaded_table_a2, clear
                rename `selection_incentive_measure' selection_incentive
                label variable hix "Marketplace"
                label variable selection_incentive "Selection incentive"
                unique therapeutic_class
                local classes = `r(sum)'
                local observations = `r(N)'
                rename `cost_grouping' cost_grouping
                xi i.hix*i.cost_grouping
                eststo: areg `grouping' 1.hix#c.selection_incentive _IhixXcos_1_* ///
                    i.therapeutic_class [aw=coveredlives], ///
                    a(organizationid) cluster(therapeutic_class)
                estadd local therapeutic_class_fe "X"
                estadd local plan_fe "X"
                estadd local classes "`classes'"
                estadd local observations "`observations'"
                estadd local cost_grouping "${`cost_grouping'_l}"
            }
        }
        esttab using ../output/tables/A2.csv, ///
            b(%9.3fc) se(%9.3fc) parentheses star(* 0.1 ** 0.05 *** 0.01) noobs label ///
            keep(1.hix#c.selection_incentive) ///
            scalars("therapeutic_class_fe Therapeutic Class FE" "plan_fe Plan FE" ///
                "cost_grouping Cost bins" ///
                "classes Classes" "observations Observations (Plan x Class)") ///
            mtitles("high_pct" "high_pct" "high_pct" "high_pct" ///
                "non_tier_pct" "non_tier_pct" "non_tier_pct" "non_tier_pct") ///
            title("`selection_incentive_measure'") append
        eststo clear
    }

end

program table_a3

    global brand_high "specialty_pct not_listed_pct medical_pct not_covered_pct *_past_pct"
    global generic_high "generic_pct *_past_pct not_covered_pct not_listed_pct"

    foreach type in brand generic {
        use ${payments}, clear
        merge 1:m therapeutic_class using ${tier_data_`type'},assert(1 3) keep(3) keepusing(*) nogen
        drop if pbmid==-1
        egen past_pct = rowtotal(*_past_pct)
        save ../temp/data_loaded_table_a3_`type', replace
    }

    foreach type in brand generic {
        foreach plan_type in 1 2 {
            use ../temp/data_loaded_table_a3_`type', clear
            drop if number_with_any_spending==0
            collapse (mean) plan_type coveredlives generic_preferred_pct generic_pct ///
                preferred_pct covered_pct specialty_pct not_listed_pct medical_pct past_pct ///
                not_covered_pct, by(organizationid)
            foreach var of varlist generic_preferred_pct generic_pct preferred_pct ///
                covered_pct specialty_pct not_listed_pct medical_pct past_pct not_covered_pct {
                sum `var' if plan_type==`plan_type' [aw=coveredlives], meanonly
                matrix table_a_3_`type'_`plan_type' = nullmat(table_a_3_`type'_`plan_type') \ ///
                    round(`r(mean)',0.001)
            }
            use ../temp/data_loaded_table_a3_`type', clear
            unique therapeutic_class if plan_type==`plan_type'
            matrix table_a_3_`type'_`plan_type' = table_a_3_`type'_`plan_type' \ `r(sum)'
        }
    }
    matrix table_a_3 = table_a_3_brand_1, table_a_3_brand_2, ///
        table_a_3_generic_1, table_a_3_generic_2
    matrix rownames table_a_3 = ///
        "Mean_percent_generic_preferred" "Mean_percent_generic" "Mean_percent_preferred" ///
        "Mean_percent_covered" "Mean_percent_specialty" "Mean_percent_not_listed" ///
        "Mean_percent_medical" "Mean_percent_PA/ST" "Mean_percent_not_covered" "Therapeutic_classes" 
    matrix colnames table_a_3 = "Brand_Employer_plans" "Brand_Exchange_plans" ///
        "Generic_Employer_plans" "Generic_Exchange_plans"
    estout matrix(table_a_3) using  ../output/tables/A3.xls, replace

end

program table_a4
    matrix drop _all
    use ${cciio_data}, clear
    cap drop tagPlanTier
    egen tagPlanTier = tag(StandardComponentId tier csr)
    cap drop sample*
    gen sample1 = tagPlanTier==1
    gen sampleNoCoins = Icoins==0 & tagPlanTier==1
    foreach metal in Bronze Silver Silver87 Silver94 Gold Platinum {
        foreach tier in 1 2 3 4 { 
            sum max`metal'Copay if tier ==`tier' & MetalLevel=="`metal'" & sampleNoCoins==1 
            matrix `metal'_nocoins = nullmat(`metal'_nocoins) \ `r(mean)'
            count if tier==`tier' & MetalLevel=="`metal'" & sample1==1 
            local N_plans = `r(N)'
            count if tier==`tier' & MetalLevel=="`metal'" & sampleNoCoins==0
            local N_coins = `r(N)'
            local coins_pct = `N_coins' / `N_plans'
            matrix `metal'_pct_coins = nullmat(`metal'_pct_coins) \ `coins_pct'
            summ subjDed if tier==`tier' & Metal=="`metal'"  & tagPlanTier==1
            matrix `metal'_pct_ded = nullmat(`metal'_pct_ded) \ `r(mean)'
        }
        matrix Table_A4 = nullmat(Table_A4), `metal'_nocoins, `metal'_pct_coins, `metal'_pct_ded
    }
    matrix rownames Table_A4 = "Generic" "PreferredBrand" "Non-PreferredBrand" "Specialty"
    matrix colnames Table_A4 =  "BronzeNoCoins" "BronzePctCoins" "BronzePctDed" ///
        "SilverNoCoins" "SilverPctCoins" "SilverPctDed" ///
        "Silver87NoCoins" "Silver87PctCoins" "Silver87PctDed" ///
        "Silver94NoCoins" "Silver94PctCoins" "Silver94PctDed" ///
        "GoldNoCoins" "GoldPctCoins" "GoldPctDed" ///
        "PlatinumNoCoins" "PlatinumPctCoins" "PlatinumPctDed"
   estout matrix(Table_A4) using  ../output/tables/A4.xls, replace
end

program table_a5

    global brand_high "specialty_pct not_listed_pct medical_pct not_covered_pct *_past_pct"
    global generic_high "generic_pct *_past_pct not_covered_pct not_listed_pct"

    foreach type in brand generic {
        use ${payments}, clear
        merge 1:m therapeutic_class using ${tier_data_`type'},assert(1 3) keep(3) keepusing(*) nogen
        drop if pbmid==-1
        egen high_pct = rowtotal(${`type'_high})
        save ../temp/data_loaded_table_a5_`type', replace
    }

    foreach selection_incentive_measure in spend_rev_ratio_std spend_rev_diff_std ///
        ellis_mcguire_std {
        use ../temp/data_loaded_table_a5_brand, clear
        rename `selection_incentive_measure' selection_incentive
        label variable hix "Marketplace"
        label variable selection_incentive "Selection incentive"
        unique therapeutic_class
        local classes = `r(sum)'
        local observations = `r(N)'
        eststo: areg high_pct 1.hix#c.selection_incentive ///
            i.therapeutic_class [aw=coveredlives], a(organizationid) cluster(therapeutic_class)
        estadd local therapeutic_class_fe "X"
        estadd local plan_fe "X"
        estadd local classes "`classes'"
        estadd local observations "`observations'"
    }
    esttab using ../output/tables/A5.csv, b(%9.3fc) se(%9.3fc) parentheses ///
        star(* 0.1 ** 0.05 *** 0.01) noobs label ///
        keep(1.hix#c.selection_incentive) ///
        scalars("therapeutic_class_fe Therapeutic Class FE" "plan_fe Plan FE" ///
            "classes Classes" "observations Observations (Plan x Class)") ///
        mtitles("Ratio" "Difference" "Ellis-McGuire") title("Panel A: Branded Drugs Only") replace
    eststo clear

    foreach selection_incentive_measure in spend_rev_ratio_std spend_rev_diff_std ///
        ellis_mcguire_std {
        use ../temp/data_loaded_table_a5_generic, clear
        rename `selection_incentive_measure' selection_incentive
        label variable hix "Marketplace"
        label variable selection_incentive "Selection incentive"
        unique therapeutic_class
        local classes = `r(sum)'
        local observations = `r(N)'
        eststo: areg high_pct 1.hix#c.selection_incentive ///
            i.therapeutic_class [aw=coveredlives], a(organizationid) cluster(therapeutic_class)
        estadd local therapeutic_class_fe "X"
        estadd local plan_fe "X"
        estadd local classes "`classes'"
        estadd local observations "`observations'"
    }
    esttab using ../output/tables/A5.csv, b(%9.3fc) se(%9.3fc) parentheses ///
        star(* 0.1 ** 0.05 *** 0.01) noobs label ///
        keep(1.hix#c.selection_incentive) ///
        scalars("therapeutic_class_fe Therapeutic Class FE" "plan_fe Plan FE" ///
            "classes Classes" "observations Observations (Plan x Class)") ///
        mtitles("Ratio" "Difference" "Ellis-McGuire") title("Panel B: Generic Drugs Only") append
    eststo clear

end

program table_a6

    use ${payments}, clear
    merge 1:m therapeutic_class using ${tier_data}, assert(1 3) keep(3) keepusing(*) nogen
    drop if pbmid==-1
    save ../temp/data_loaded_table_a6, replace

    foreach selection_incentive_measure in spend_rev_ratio_std spend_rev_diff_std ///
        ellis_mcguire_std {
        use ../temp/data_loaded_table_a6 if number_of_drugs_in_class_generic==0, clear
        rename `selection_incentive_measure' selection_incentive
        label variable hix "Marketplace"
        label variable selection_incentive "Selection incentive"
        unique therapeutic_class
        local classes = `r(sum)'
        local observations = `r(N)'
        eststo: areg high_pct 1.hix#c.selection_incentive ///
            i.therapeutic_class [fw=coveredlives], a(organizationid) cluster(therapeutic_class)
        estadd local therapeutic_class_fe "X"
        estadd local plan_fe "X"
        estadd local classes "`classes'"
        estadd local observations "`observations'"
    }
    esttab using ../output/tables/A6.csv, b(%15.2gc) se(%15.2gc) parentheses ///
        star(* 0.1 ** 0.05 *** 0.01) noobs label ///
        keep(1.hix#c.selection_incentive) ///
        scalars("therapeutic_class_fe Therapeutic Class FE" "plan_fe Plan FE" "classes Classes" ///
            "observations Observations (Plan x Class)") ///
        mtitles("Ratio" "Difference" "Ellis-McGuire") ///
        title("Panel A: Classes with No Generics") replace
    eststo clear

    foreach selection_incentive_measure in spend_rev_ratio_std spend_rev_diff_std ///
        ellis_mcguire_std {
        use ../temp/data_loaded_table_a6 if pct_of_drugs_in_class_generic<0.1, clear
        rename `selection_incentive_measure' selection_incentive
        label variable hix "Marketplace"
        label variable selection_incentive "Selection incentive"
        label variable pct_of_drugs_in_class_generic "Percent of drugs in class generic"
        unique therapeutic_class
        local classes = `r(sum)'
        local observations = `r(N)'
        eststo: areg high_pct 1.hix#c.selection_incentive ///
            i.therapeutic_class [fw=coveredlives], a(organizationid) cluster(therapeutic_class)
        estadd local therapeutic_class_fe "X"
        estadd local plan_fe "X"
        estadd local classes "`classes'"
        estadd local observations "`observations'"
    }
    esttab using ../output/tables/A6.csv, b(%15.2gc) se(%15.2gc) parentheses ///
        star(* 0.1 ** 0.05 *** 0.01) noobs label ///
        keep(1.hix#c.selection_incentive) ///
        scalars("therapeutic_class_fe Therapeutic Class FE" "plan_fe Plan FE" "classes Classes" ///
            "observations Observations (Plan x Class)") ///
        mtitles("Ratio" "Difference" "Ellis-McGuire") ///
        title("Panel B: Classes with less than 10% Generics") append
    eststo clear

    foreach selection_incentive_measure in spend_rev_ratio_std spend_rev_diff_std ///
        ellis_mcguire_std {
        use ../temp/data_loaded_table_a6 if pct_of_drugs_in_class_generic<0.25, clear
        rename `selection_incentive_measure' selection_incentive
        label variable hix "Marketplace"
        label variable selection_incentive "Selection incentive"
        label variable pct_of_drugs_in_class_generic "Percent of drugs in class generic"
        unique therapeutic_class
        local classes = `r(sum)'
        local observations = `r(N)'
        eststo: areg high_pct 1.hix#c.selection_incentive ///
            i.therapeutic_class [fw=coveredlives], a(organizationid) cluster(therapeutic_class)
        estadd local therapeutic_class_fe "X"
        estadd local plan_fe "X"
        estadd local classes "`classes'"
        estadd local observations "`observations'"
    }
    esttab using ../output/tables/A6.csv, b(%15.2gc) se(%15.2gc) parentheses ///
        star(* 0.1 ** 0.05 *** 0.01) noobs label ///
        keep(1.hix#c.selection_incentive) ///
        scalars("therapeutic_class_fe Therapeutic Class FE" "plan_fe Plan FE" "classes Classes" ///
            "observations Observations (Plan x Class)") ///
        mtitles("Ratio" "Difference" "Ellis-McGuire") ///
        title("Panel C: Classes with less than 25% Generics") append
    eststo clear

end

program table_a7

    use ${payments}, clear
    merge 1:m therapeutic_class using ${tier_data}, assert(1 3) keep(3) keepusing(*) nogen
    drop if pbmid==-1
    save ../temp/data_loaded_table_a7, replace

    foreach selection_incentive_measure in spend_rev_ratio_std spend_rev_diff_std ///
        ellis_mcguire_std {
        use ../temp/data_loaded_table_a7, clear
        rename `selection_incentive_measure' selection_incentive
        label variable hix "Marketplace"
        label variable selection_incentive "Selection incentive"
        label variable pct_of_drugs_in_class_generic "Percent of drugs in class generic"
        unique therapeutic_class
        local classes = `r(sum)'
        local observations = `r(N)'
        eststo: areg high_pct 1.hix#c.selection_incentive ///
            1.hix#c.pct_of_drugs_in_class_generic i.therapeutic_class [fw=coveredlives], ///
            a(organizationid) cluster(therapeutic_class)
        estadd local therapeutic_class_fe "X"
        estadd local plan_fe "X"
        estadd local classes "`classes'"
        estadd local observations "`observations'"
    }
    esttab using ../output/tables/A7.csv, b(%15.2gc) se(%15.2gc) parentheses ///
        star(* 0.1 ** 0.05 *** 0.01) noobs label ///
        keep(1.hix#c.selection_incentive 1.hix#c.pct_of_drugs_in_class_generic) ///
        scalars("therapeutic_class_fe Therapeutic Class FE" "plan_fe Plan FE" "classes Classes" ///
            "observations Observations (Plan x Class)") ///
        mtitles("Ratio" "Difference" "Ellis-McGuire") ///
        title("Robustness: Controlling for Exchange x Fraction Generic in Class") replace
    eststo clear

end

program table_a8

    use ${payments}, clear
    merge 1:m therapeutic_class using ${tier_data}, assert(1 3) keep(3) keepusing(*) nogen
    drop if pbmid==-1
    drop if therapeutic_class==169|therapeutic_class==171|therapeutic_class==246
    save ../temp/data_loaded_table_a8, replace

    foreach selection_incentive_measure in spend_rev_ratio_std spend_rev_diff_std ///
        ellis_mcguire_std {
        use ../temp/data_loaded_table_a8, clear
        rename `selection_incentive_measure' selection_incentive
        label variable hix "Marketplace"
        label variable selection_incentive "Selection incentive"
        unique therapeutic_class
        local classes = `r(sum)'
        local observations = `r(N)'
        eststo: areg high_pct 1.hix#c.selection_incentive ///
            i.therapeutic_class [fw=coveredlives], a(organizationid) cluster(therapeutic_class)
        estadd local htherapeutic_class_fe "X"
        estadd local plan_fe "X"
        estadd local classes "`classes'"
        estadd local observations "`observations'"
    }
    esttab using ../output/tables/A8.csv, b(%15.2gc) se(%15.2gc) parentheses ///
        star(* 0.1 ** 0.05 *** 0.01) noobs label keep(1.hix#c.selection_incentive) ///
        scalars("therapeutic_class_fe Therapeutic Class FE" "plan_fe Plan FE" "classes Classes" ///
            "observations Observations (Plan x Class)") ///
        mtitles("Ratio" "Difference" "Ellis-McGuire") ///
        title("Robustness: Removing Fertility Treatment Classes from Analysis") replace
    eststo clear

end

program table_a9

    use ${payments}, clear
    foreach selection_incentive_measure in spend_rev_ratio_std spend_rev_diff_std ///
        ellis_mcguire_std {
        xtile `selection_incentive_measure'_ventile = `selection_incentive_measure', nquantiles(20)
        tab `selection_incentive_measure'_ventile, gen(`selection_incentive_measure'_ventile_)
    }
    merge 1:m therapeutic_class using ${tier_data}, assert(1 3) keep(3) keepusing(*) nogen
    drop if pbmid==-1
    save ../temp/data_loaded_table_a9, replace

    foreach selection_incentive_measure in spend_rev_ratio_std ellis_mcguire_std {
        use ../temp/data_loaded_table_a9, clear
        bys pbmid: gen N=_N
        drop if N<10000
        rename `selection_incentive_measure' selection_incentive
        rename `selection_incentive_measure'_ventile_20 selection_incentive_ventile_20
        label variable hix "Marketplace"
        label variable selection_incentive "Selection incentive"
        label variable selection_incentive_ventile_20 "Selection incentive ventile 20"
        unique therapeutic_class
        local classes = `r(sum)'
        local observations = `r(N)'
        eststo: areg high_pct 1.hix#c.selection_incentive i.pbmid#c.selection_incentive ///
            i.therapeutic_class [fw=coveredlives], a(organizationid) cluster(therapeutic_class)
        estadd local htherapeutic_class_fe "X"
        estadd local plan_fe "X"
        estadd local pbm_selection "X"
        estadd local classes "`classes'"
        estadd local observations "`observations'"
        eststo: areg high_pct 1.hix#c.selection_incentive ///
            1.hix#1.selection_incentive_ventile_20 i.pbmid#c.selection_incentive ///
            i.therapeutic_class [fw=coveredlives], a(organizationid) cluster(therapeutic_class)
        estadd local htherapeutic_class_fe "X"
        estadd local plan_fe "X"
        estadd local pbm_selection "X"
        estadd local classes "`classes'"
        estadd local observations "`observations'"
    }
    foreach selection_incentive_measure in spend_rev_ratio_std ellis_mcguire_std {
        use ../temp/data_loaded_table_a9, clear
        bys pbm_state: gen N=_N
        drop if N<1000
        rename `selection_incentive_measure' selection_incentive
        rename `selection_incentive_measure'_ventile_20 selection_incentive_ventile_20
        label variable hix "Marketplace"
        label variable selection_incentive "Selection incentive"
        label variable selection_incentive_ventile_20 "Selection incentive ventile 20"
        unique therapeutic_class
        local classes = `r(sum)'
        local observations = `r(N)'
        eststo: areg high_pct 1.hix#c.selection_incentive i.pbm_state#c.selection_incentive ///
            i.therapeutic_class [fw=coveredlives], a(organizationid) cluster(therapeutic_class)
        estadd local htherapeutic_class_fe "X"
        estadd local plan_fe "X"
        estadd local pbm_state_selection "X"
        estadd local classes "`classes'"
        estadd local observations "`observations'"
        eststo: areg high_pct 1.hix#c.selection_incentive ///
            1.hix#1.selection_incentive_ventile_20 ///
            i.pbm_state#c.selection_incentive ///
            i.therapeutic_class [fw=coveredlives], a(organizationid) cluster(therapeutic_class)
        estadd local htherapeutic_class_fe "X"
        estadd local plan_fe "X"
        estadd local pbm_selection "No"
        estadd local pbm_state_selection "X"
        estadd local classes "`classes'"
        estadd local observations "`observations'"
    }
    esttab using ../output/tables/A9.csv, ///
        b(%9.3fc) se(%9.3fc) parentheses star(* 0.1 ** 0.05 *** 0.01) noobs label ///
        keep(1.hix#c.selection_incentive 1.hix#1.selection_incentive_ventile_20) ///
        scalars("therapeutic_class_fe Therapeutic Class FE" "plan_fe Plan FE" ///
            "pbm_selection PBM x Selection incentive" ///
            "pbm_state_selection PBM x State x Selection incentive" ///
            "classes Classes" "observations Observations (Plan x Class)") ///
        mtitles("Ratio" "Ratio" "Ellis-McGuire" "Ellis-McGuire" ///
            "Ratio" "Ratio" "Ellis-McGuire" "Ellis-McGuire") ///
        title("Robustness: Patterns Persist within Pharmacy Benefit Managers") replace
    eststo clear

end

program table_a10

    use ${payments_ahfs} , clear
    merge 1:m therapeutic_class using ${tier_data_ahfs}, assert(1 3) keep(3) keepusing(*) nogen
    drop if pbmid==-1
    save ../temp/data_loaded_table_a10, replace

    foreach selection_incentive_measure in spend_rev_ratio_std spend_rev_diff_std ///
        ellis_mcguire_std {   
        use ../temp/data_loaded_table_a10, clear
        rename `selection_incentive_measure' selection_incentive
        label variable hix "Marketplace"
        label variable selection_incentive "Selection incentive"
        unique therapeutic_class
        local classes = `r(sum)'
        local observations = `r(N)'
        eststo: areg high_pct 1.hix#c.selection_incentive ///
            i.therapeutic_class [fw=coveredlives], a(organizationid) cluster(therapeutic_class)
        estadd local therapeutic_class_fe "Yes"
        estadd local plan_fe "Yes"
        estadd local classes "`classes'"
        estadd local observations "`observations'"
        use ../temp/data_loaded_table_a10 if elasticity!=., clear
        rename `selection_incentive_measure' selection_incentive
        label variable hix "Marketplace"
        label variable selection_incentive "Selection incentive"
        unique therapeutic_class
        local classes = `r(sum)'
        local observations = `r(N)'
        eststo: areg high_pct 1.hix#c.selection_incentive ///
            i.therapeutic_class [fw=coveredlives], a(organizationid) cluster(therapeutic_class)
        estadd local therapeutic_class_fe "Yes"
        estadd local plan_fe "Yes"
        estadd local classes "`classes'"
        estadd local observations "`observations'"
        eststo: areg high_pct 1.hix#c.selection_incentive 1.hix#c.elasticity ///
            i.therapeutic_class [fw=coveredlives], a(organizationid) cluster(therapeutic_class)
        estadd local therapeutic_class_fe "Yes"
        estadd local plan_fe "Yes"
        estadd local classes "`classes'"
        estadd local observations "`observations'"
    }
    esttab using ../output/tables/A10.csv, b(%9.3fc) se(%9.3fc) ///
        parentheses star(* 0.1 ** 0.05 *** 0.01) noobs label ///
        keep(1.hix#c.selection_incentive 1.hix#c.elasticity) ///
        scalars("therapeutic_class_fe Therapeutic Class FE" "plan_fe Plan FE" ///
            "classes Classes" "observations Observations (Plan x Class)") ///
        mtitles("Ratio" "Ratio" "Ratio" "Difference" "Difference" "Difference" ///
            "Ellis-McGuire" "Ellis-McGuire" "Ellis-McGuire") ///
        title("Panel A: Fraction of Class Tiered Specialty or Higher") replace
    eststo clear

    foreach selection_incentive_measure in spend_rev_ratio_std spend_rev_diff_std ///
        ellis_mcguire_std {   
        use ../temp/data_loaded_table_a10, clear
        rename `selection_incentive_measure' selection_incentive
        label variable hix "Marketplace"
        label variable selection_incentive "Selection incentive"
        unique therapeutic_class
        local classes = `r(sum)'
        local observations = `r(N)'
        eststo: areg non_tier_pct 1.hix#c.selection_incentive ///
            i.therapeutic_class [fw=coveredlives], a(organizationid) cluster(therapeutic_class)
        estadd local therapeutic_class_fe "Yes"
        estadd local plan_fe "Yes"
        estadd local classes "`classes'"
        estadd local observations "`observations'"
        use ../temp/data_loaded_table_a10 if elasticity!=., clear
        rename `selection_incentive_measure' selection_incentive
        label variable hix "Marketplace"
        label variable selection_incentive "Selection incentive"
        unique therapeutic_class
        local classes = `r(sum)'
        local observations = `r(N)'
        eststo: areg non_tier_pct 1.hix#c.selection_incentive ///
            i.therapeutic_class [fw=coveredlives], a(organizationid) cluster(therapeutic_class)
        estadd local therapeutic_class_fe "Yes"
        estadd local plan_fe "Yes"
        estadd local classes "`classes'"
        estadd local observations "`observations'"
        eststo: areg non_tier_pct 1.hix#c.selection_incentive 1.hix#c.elasticity ///
            i.therapeutic_class [fw=coveredlives], a(organizationid) cluster(therapeutic_class)
        estadd local therapeutic_class_fe "Yes"
        estadd local plan_fe "Yes"
        estadd local classes "`classes'"
        estadd local observations "`observations'"
    }
    esttab using ../output/tables/A10.csv, b(%9.3fc) se(%9.3fc) ///
        parentheses star(* 0.1 ** 0.05 *** 0.01) noobs label ///
        keep(1.hix#c.selection_incentive 1.hix#c.elasticity) ///
        scalars("therapeutic_class_fe Therapeutic Class FE" "plan_fe Plan FE" ///
            "classes Classes" "observations Observations (Plan x Class)") ///
        mtitles("Ratio" "Ratio" "Ratio" "Difference" "Difference" "Difference" ///
            "Ellis-McGuire" "Ellis-McGuire" "Ellis-McGuire") ///
        title("Panel B: Fraction of Class Tiered Prior Auth./Step Therapy/Not Covered") append
    eststo clear

end

*Execute
main
